#
# spec file for package collectd
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2005-2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define plugins apache apcups aggregation ascent battery bind  \\\
  capabilities ceph cgroups chrony curl curl_json curl_xml conntrack contextswitch cpu cpufreq cpusleep csv \\\
  df disk dns drbd \\\
  email entropy ethstat exec fhcount filecount fscache hddtemp hugepages \\\
  infiniband %{expand:%{rdt_plugin}} interface ipc iptables ipvs irq \\\
  load logfile log_logstash \\\
  madwifi match_empty_counter match_hashed match_regex match_timediff match_value \\\
  mdevents mbmon md memcached memory mmc multimeter \\\
  netlink network nfs nginx notify_nagios ntpd numa olsrd openvpn \\\
  perl ping protocols powerdns processes \\\
  rrdcached rrdtool %{expand:%{sensors_plugin}} serial statsd swap syslog \\\
  table tail tail_csv target_notification target_replace target_scale target_set target_v5upgrade \\\
  tcpconns teamspeak2 ted thermal threshold \\\
  unixsock uptime users uuid vmem vserver \\\
  wireless write_graphite write_http write_log write_sensu write_tsdb \\\
  write_prometheus zfs_arc zookeeper
%ifnarch s390 s390x
%bcond_without sensors
%define sensors_plugin sensors
%else
%bcond_with sensors
%define sensors_plugin %{nil}
%endif
# dpdk exclusive build arch requirements copied:
%ifarch aarch64 x86_64 ppc64le
%bcond_without dpdk
%else
%bcond_with dpdk
%endif
%ifarch x86_64 %{ix86}
%bcond_without intel_rdt
%define rdt_plugin intel_rdt
%else
%bcond_with intel_rdt
%define rdt_plugin %{nil}
%endif
%if 0%{?suse_version} >= 1330 && 0%{?suse_version} <= 1500
%bcond_without nut
%else
%bcond_with nut
%endif
%bcond_with epics
Name:           collectd
Version:        5.12.0.348.g93f9bdcb
Release:        2.1
Summary:        Statistics Collection Daemon for filling RRD Files
License:        GPL-2.0-only AND MIT
Group:          System/Monitoring
URL:            http://collectd.org/
# Source:         http://collectd.org/files/collectd-%%{version}.tar.bz2
Source:         collectd-%{version}.tar.bz2
Source1:        collectd.suse.init
Source2:        collectd.apache2.conf
Source3:        collectd-js.apache2.conf
Source99:       collectd-rpmlintrc
Patch1:         collectd-fix-config.patch
Patch2:         collectd-version.patch
Patch3:         collectd-perl-vendor.patch
# see http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=467072
Patch4:         collectd-fix_broken_perl-5.10.patch
Patch5:         collectd-fix_collection_cgi.patch
Patch6:         collectd-fix_spamassassin_doc.patch
Patch7:         collectd-fix_collectd_config_path_in_snmp_probe.patch
Patch8:         9e36cd85a2bb_sigrok_Update_to_support_libsigrok_0_4.patch
# PATCH-FIX-OPENSUSE avoid-pg-config.patch avoid pg_config if possible
Patch11:        avoid-pg-config.patch
Patch12:        harden_collectd.service.patch
# for /etc/apache2/... ownership (rpmlint):
BuildRequires:  apache2
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  gdbm-devel
BuildRequires:  gettext-devel
BuildRequires:  intltool
BuildRequires:  java-devel
BuildRequires:  libesmtp-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libjansson-devel
BuildRequires:  libnetlink-devel
BuildRequires:  libpcap-devel
BuildRequires:  libpng-devel
BuildRequires:  libprotobuf-c-devel
BuildRequires:  libtool
BuildRequires:  libyajl-devel
BuildRequires:  linux-kernel-headers
BuildRequires:  make
BuildRequires:  mysql-devel >= 4.1.0
BuildRequires:  net-snmp-devel
BuildRequires:  openldap2-devel
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  postgresql-devel
BuildRequires:  rrdtool
BuildRequires:  systemd-rpm-macros
BuildRequires:  xfsprogs-devel
BuildRequires:  pkgconfig(OpenIPMI)
BuildRequires:  pkgconfig(OpenIPMIpthread)
BuildRequires:  pkgconfig(dbi)
BuildRequires:  pkgconfig(libatasmart)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libiptc)
BuildRequires:  pkgconfig(libmemcached)
BuildRequires:  pkgconfig(libmicrohttpd)
BuildRequires:  pkgconfig(libmnl)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(liboping)
BuildRequires:  pkgconfig(libpq)
BuildRequires:  pkgconfig(librrd)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libvirt)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(xtables)
BuildRequires:  pkgconfig(zlib)
Requires:       rrdtool
Requires(post): %fillup_prereq
# play nice with collectd-beta:
Obsoletes:      collectd-beta < %{version}
Provides:       collectd-beta = %{version}-%{release}
%{?systemd_requires}
%if %{with dpdk}
BuildRequires:  dpdk-devel >= 19.08
%endif
# intel_rdt -> pqos.h
# intel-cmt-cat exclusive build arch requirements copied:
%if %{with intel_rdt}
BuildRequires:  libpqos-devel
%endif
%if 0%{?sle_version} < 150000 || 0%{?is_opensuse}
BuildRequires:  pkgconfig(Qgpsmm)
BuildRequires:  pkgconfig(libgps)
BuildRequires:  pkgconfig(libsigrok)
%endif
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150400
BuildRequires:  pkgconfig(libmodbus)
BuildRequires:  strip-nondeterminism
%endif
%if 0%{?is_opensuse}
BuildRequires:  pkgconfig(libmosquitto)
%endif
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
BuildRequires:  pkgconfig(librabbitmq)
%endif
%if %{with nut}
BuildRequires:  pkgconfig(libnutclient)
%endif
%if %{with sensors}
BuildRequires:  sensors
Requires:       sensors
%endif
%if %{with epics}
BuildRequires:  epics-devel
%endif

%description
collectd is a daemon (written in C) that reads various system
statistics and updates RRD files. Statistics are very fine grained
with an update interval of 10 seconds.

%package web
Summary:        Web Frontend for watching the %{name} Statistics
Group:          System/Monitoring
Requires:       apache2
Requires:       perl
Requires:       rrdtool
Requires:       perl(CGI)
Requires:       perl(Data::Dumper)
Requires:       perl(HTML::Entities)
Requires:       perl(RRDs)
Requires:       perl(URI::Escape)
BuildArch:      noarch

%description web
Web frontend CGI for watching %{name} statistics from a browser.

Please look at %{_sysconfdir}/apache2/conf.d/%{name}.conf on how to enable.

%package web-js
Summary:        Web/JavaScript Frontend for watching %{name} Statistics
Group:          System/Monitoring
Requires:       apache2
Requires:       perl
Requires:       rrdtool
Requires:       perl(CGI)
Requires:       perl(Config::General)
Requires:       perl(Data::Dumper)
Requires:       perl(HTML::Entities)
Requires:       perl(JSON)
Requires:       perl(RRDs)
BuildArch:      noarch

%description web-js
Web/JavaScript frontend CGI for watching %{name} statistics from
a browser.

Please look at %{_sysconfdir}/apache2/conf.d/%{name}-js.conf on how to
enable.

%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
%package plugin-amqp
Summary:        AMQP Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-amqp
The AMQP plugin transmits or receives values collected by collectd via the
Advanced Message Queuing Protocol (AMQP).
%endif

%if %{with epics}
%package plugin-epics
Summary:        EPICS CA Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}
Recommends:     epics-caRepeater

%description plugin-epics
EPICS CA for %{name} allow you to receive variables updates from the bus.
%endif

%package plugin-notify-desktop
Summary:        Desktop Notification Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-notify-desktop
Desktop Notification Support for %{name} allow you to receive
message delivery on your desktop.

%package plugin-ipmi
Summary:        OpenIPMI Monitoring Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-ipmi
Optional %{name} plugin to monitor sensors using the OpenIPMI
library for IPMI enabled systems.

%package plugin-snmp
Summary:        SNMP Monitoring Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}
Requires:       perl(Config::General)
Requires:       perl(SNMP)
Requires:       perl(Socket6)

%description plugin-snmp
Optional %{name} plugin to monitor devices using SNMP.

%package plugin-mysql
Summary:        MySQL Monitoring Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-mysql
Optional %{name} plugin to monitor MySQL server instances.

%package plugin-openldap
Summary:        OpenLDAP plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-openldap
This plugin for collectd reads monitoring information
from OpenLDAP's cn=Monitor subtree.

%if %{with nut}
%package plugin-nut
Summary:        Network UPS Tools plugin for collectd
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-nut
This plugin for collectd provides Network UPS Tools support.
%endif

%package plugin-pcie
Summary:        PCIe Monitoring Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-pcie
Optional %{name} plugin to monitor PCIe errors.

%package plugin-postgresql
Summary:        PostgreSQL Monitoring Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-postgresql
Optional %{name} plugin to monitor PostgreSQL server instances.

%package plugin-python3
Summary:        Python3 API for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-python3
Optional %{name} Python3 API in order to write %{name} plugins in
Python3.

%package plugin-java
Summary:        Java API for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-java
Optional %{name} Java API in order to write %{name} plugins in
Java.

%package plugin-virt
Summary:        Virtual Machine Statistics Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-virt
Optional %{name} plugin to gather statistics from virtual
machines using libvirt.

%package plugin-dbi
Summary:        DBI Storage Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-dbi
Optional %{name} plugin to store sampling results into
various databases as supported by libdbi.

%package plugin-memcachec
Summary:        Memcache Daemon Monitoring Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-memcachec
Optional %{name} plugin to sample memcached statistics.

%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150400
%package plugin-modbus
Summary:        TCP Modbus Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-modbus
Optional %{name} plugin to communicate with TCP Modbus devices.
%endif

%if 0%{?is_opensuse}
%package plugin-mqtt
Summary:        MQTT Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-mqtt
Optional %{name} plugin to send and receive MQTT messages.
%endif

%package plugin-pinba
Summary:        Pinba Collector Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-pinba
Optional %{name} plugin to receive and dispatch timing values from Pinba, a
profiling extension for PHP.

%if 0%{?sle_version} < 150000 || 0%{?is_opensuse}
%package plugin-sigrok
Summary:        Sigrok Monitoring Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-sigrok
Optional %{name} plugin to collect measurements from
various devices supported by libsigrok.
%endif

%package plugin-smart
Summary:        SMART Monitoring Plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-smart
Optional %{name} plugin to monitor Self-Monitoring, Analysis and Reporting
Technology (SMART) information from disk drives.

%package plugin-lua
Summary:        Lua API for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}
Requires:       lua

%description plugin-lua
Optional %{name} Lua API in order to write %{name} plugins in Lua.

%if 0%{?sle_version} < 150000 || 0%{?is_opensuse}
%package plugin-gps
Summary:        GPSD monitoring plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-gps
Optional %{name} plugin to monitor gpsd.
%endif

%package plugin-mcelog
Summary:        Machine Check Exceptions plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-mcelog
Optional %{name} plugin to monitor machine check exceptions.

%package plugin-ovs
Summary:        Open vSwitch (OVS) plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-ovs
Optional %{name} plugin to monitor an OVS database.

%package plugin-synproxy
Summary:        Synproxy stats plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-synproxy
Optional %{name} plugin to monitor Synproxy stats.

%package plugin-write_stackdriver
Summary:        Write Stackdriver plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-write_stackdriver
Optional %{name} plugin to to write to Google Stackdriver.

%package plugin-write_syslog
Summary:        Write Syslog plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-write_syslog
Optional %{name} plugin to write values lists as syslog messages.

%package plugin-uptime
Summary:        Uptime plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-uptime
Optional %{name} plugin to collect system uptime statistics.

%package plugin-connectivity
Summary:        Connectivity plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-connectivity
Optional %{name} plugin to collect Event-based interface status.

%package plugin-procevent
Summary:        Procevent plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-procevent
Optional %{name} plugin to listen for process starts and exits via netlink.

%package plugin-sysevent
Summary:        Sysevent plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-sysevent
Optional %{name} plugin to listen to rsyslog events and submit matched values.
.

%package plugin-buddyinfo
Summary:        Buddyinfo plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-buddyinfo
Optional %{name} plugin for memory fragmentation.

%package plugin-logparser
Summary:        Logparser plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-logparser
Optional %{name} plugin for filtering and parsing logs.

%package plugin-ubi
Summary:        UBIFS plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-ubi
Optional %{name} plugin for reporting block state of flash memory devices with UBIFS filesystem.

%package plugin-write_influxdb_udp
Summary:        InfluxDB UDP protocol plugin for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-write_influxdb_udp
Optional %{name} plugin to send values to InfluxDB using line protocol via udp.
For HTTP line protocol use write_http plugin.

%package plugins-all
Summary:        All Monitoring Plugins for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-plugin-buddyinfo = %{version}-%{release}
Requires:       %{name}-plugin-connectivity = %{version}-%{release}
Requires:       %{name}-plugin-dbi = %{version}-%{release}
Requires:       %{name}-plugin-ipmi = %{version}-%{release}
Requires:       %{name}-plugin-java = %{version}-%{release}
Requires:       %{name}-plugin-logparser = %{version}-%{release}
Requires:       %{name}-plugin-lua = %{version}-%{release}
Requires:       %{name}-plugin-mcelog = %{version}-%{release}
Requires:       %{name}-plugin-memcachec = %{version}-%{release}
Requires:       %{name}-plugin-mysql = %{version}-%{release}
Requires:       %{name}-plugin-notify-desktop = %{version}-%{release}
Requires:       %{name}-plugin-openldap = %{version}-%{release}
Requires:       %{name}-plugin-ovs = %{version}-%{release}
Requires:       %{name}-plugin-pcie = %{version}-%{release}
Requires:       %{name}-plugin-pinba = %{version}-%{release}
Requires:       %{name}-plugin-postgresql = %{version}-%{release}
Requires:       %{name}-plugin-procevent = %{version}-%{release}
Requires:       %{name}-plugin-python3 = %{version}-%{release}
Requires:       %{name}-plugin-smart = %{version}-%{release}
Requires:       %{name}-plugin-snmp = %{version}-%{release}
Requires:       %{name}-plugin-synproxy = %{version}-%{release}
Requires:       %{name}-plugin-sysevent = %{version}-%{release}
Requires:       %{name}-plugin-ubi = %{version}-%{release}
Requires:       %{name}-plugin-uptime = %{version}-%{release}
Requires:       %{name}-plugin-virt = %{version}-%{release}
Requires:       %{name}-plugin-write_influxdb_udp = %{version}-%{release}
Requires:       %{name}-plugin-write_stackdriver = %{version}-%{release}
Requires:       %{name}-plugin-write_syslog = %{version}-%{release}
Requires:       %{name}-web = %{version}-%{release}
Requires:       %{name}-web-js = %{version}-%{release}
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
Requires:       %{name}-plugin-amqp = %{version}-%{release}
%endif
%if 0%{?sle_version} < 150000  || 0%{?is_opensuse}
Requires:       %{name}-plugin-gps = %{version}-%{release}
%endif
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150400
Requires:       %{name}-plugin-modbus = %{version}-%{release}
%endif
%if 0%{?is_opensuse}
Requires:       %{name}-plugin-mqtt = %{version}-%{release}
%endif
%if 0%{?sle_version} < 150000 || 0%{?is_opensuse}
Requires:       %{name}-plugin-sigrok = %{version}-%{release}
%endif
%if %{with nut}
Requires:       %{name}-plugin-nut = %{version}-%{release}
%endif
BuildArch:      noarch

%description plugins-all
Metapackage that installs %{name} and all the available
monitoring plugin subpackages.

%package spamassassin
Summary:        Spamassassin Monitoring for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}
Requires:       perl-spamassassin
BuildArch:      noarch

%description spamassassin
Plugin for filling %{name} with statistics from the
SpamAsssassin anti-spam engine.

%package plugin-dpdk
Summary:        Collect DPDK interface statistics
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description plugin-dpdk
This plugin has a specific use case: monitoring DPDK applications
that don't expose stats in any other way than the DPDK xstats API.
For OVS or OVS-with-DPDK the Open vSwitch plugins (ovs) should be
used for collecting stats and events.

%package -n libcollectdclient1
Summary:        Library for %{name} clients
Group:          System/Monitoring
Provides:       libcollectdclient = %{version}-%{release}

%description -n libcollectdclient1
Library which abstracts communication with the %{name}
unixsock plugin for clients.

%package -n libcollectdclient-devel
Summary:        Development Environment for %{name} clients
Group:          Development/Libraries/C and C++
Requires:       libcollectdclient1 = %{version}-%{release}

%description -n libcollectdclient-devel
Library which abstracts communication with the %{name}
unixsock plugin for clients.
This package contains the required development environment
to write %{name} unixsock clients.

%prep
%autosetup -p1

sed -i 's|@@VERSION@@|%{version}|g' configure.ac

perl -p -i -e 's|(-L\$withval/lib)\b|${1}64|g' configure.ac configure

# unneeded files:
rm -fr \
     contrib/solaris-smf \
     contrib/redhat \
     contrib/sles*

%build
autoreconf -fiv

export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"
export KERNEL_DIR=%{_prefix}/src/linux
%configure \
    --disable-werror \
    --disable-silent-rules \
    --disable-static \
    --with-java="$JAVA_HOME/" \
    --disable-turbostat

make %{?_smp_mflags}

%install
%make_install

# delete .la files
rm -f "%{buildroot}%{_libdir}"/*.{a,la}
rm -f "%{buildroot}%{_libdir}/collectd"/*.a

sed -i '/^dependency_libs=/ s|-L'"${RPM_BUILD_DIR}/%{name}-%{version}"'/src||g' "%{buildroot}%{_libdir}/collectd/python.la"

# delete if it exists (not packaged any more on openSUSE):
rm -rf "%{buildroot}%{_localstatedir}/adm/perl-modules/%{name}"

mkdir -p _rpmdoc_/java
mv contrib/GenericJMX.conf _rpmdoc_/java/

# fix permissions:
chmod 0755 "%{buildroot}%{_libdir}/collectd"/*.so
chmod 0644 "%{buildroot}%{_libdir}/collectd"/*.la

# create /var/lib/collectd to add it to the %files section:
install -d -m 0755 "%{buildroot}%{_localstatedir}/lib/collectd"

# Apache2 configuration for the CGI frontend:
install -D -m 0644 "%{SOURCE2}" "%{buildroot}%{_sysconfdir}/apache2/conf.d/%{name}.conf"
install -D -m 0755 contrib/collection.cgi "%{buildroot}/srv/www/collectd/collection.cgi"
install -D -m 0644 contrib/collection.conf "%{buildroot}%{_sysconfdir}/collectd/collection.conf"
sed -i 's|@@LIBDIR@@|%{_libdir}|g' "%{buildroot}%{_sysconfdir}/collectd/collection.conf"
# remove it from contrib, to avoid having it end up in the main package as well:
rm contrib/collection.cgi contrib/collection.conf

%perl_process_packlist
rm -rf "%{buildroot}%{_localstatedir}/adm/perl-modules"/*

# web-js CGI frontend (_must_ be installed _after_ perl_process_packlist)
install -d "%{buildroot}/srv/www/collectd-js"
mkdir -p _rpmdoc_/web-js
mv contrib/collection3/README _rpmdoc_/web-js/README
find contrib/collection3/ -name .htaccess -exec rm {} \;
cp -a \
     contrib/collection3/bin/* \
     contrib/collection3/share/* \
     "%{buildroot}/srv/www/collectd-js/"
mkdir -p "%{buildroot}%{_libexecdir}/collectd-js"
mv contrib/collection3/lib/* "%{buildroot}%{_libexecdir}/collectd-js/"

install -D -m 0644 contrib/collection3%{_sysconfdir}/collection.conf \
     "%{buildroot}%{_sysconfdir}/collectd/collection-js.conf"
rm -fr contrib/collection3%{_sysconfdir}
install -D -m 0644 "%{SOURCE3}" "%{buildroot}%{_sysconfdir}/apache2/conf.d/%{name}-js.conf"

# spamassassin (_must_ be installed _after_ perl_process_packlist)
install -D -m0644 contrib/SpamAssassin/example.cf \
     "%{buildroot}%{_datadir}/spamassassin/99_%{name}.cf"
install -D -m0644 contrib/SpamAssassin/Collectd.pm \
     "%{buildroot}%{perl_vendorlib}/Mail/SpamAssassin/Plugin/Collectd.pm"
pod2man \
     contrib/SpamAssassin/Collectd.pm \
     > "%{buildroot}%{perl_man3dir}/Mail::SpamAssassin::Plugin::Collectd.%{perl_man3ext}"
rm -rf contrib/SpamAssassin

# cussh script from contrib:
install -m0755 contrib/cussh.pl "%{buildroot}%{_bindir}/cussh"
install -d "%{buildroot}%{_mandir}/man1"
pod2man \
     -c "Collectd UNIX Socket Shell" \
     -n "CUSSH" \
     -s 1 \
     contrib/cussh.pl > "%{buildroot}%{_mandir}/man1/cussh.1"
rm contrib/cussh.pl

# snmp:
mkdir -p _rpmdoc_/snmp
sed -n '/^snmp-data\.conf/,$ p' contrib/README > _rpmdoc_/snmp/README
sed -i '/^snmp-data\.conf/,$ d' contrib/README
mv contrib/snmp-data.conf _rpmdoc_/snmp/
sed -i 's|\(\./\)snmp-probe-host\.px|collectd-snmp-probe-host|g' contrib/snmp-probe-host.px
pod2man \
     -c "Collectd SNMP Host Probe" \
     -n "COLLECTD-SNMP-PROBE-HOST" \
     -s 1 \
     contrib/snmp-probe-host.px \
     > "%{buildroot}%{_mandir}/man1/collectd-snmp-probe-host.1"
install -D -m0755 contrib/snmp-probe-host.px "%{buildroot}%{_bindir}/collectd-snmp-probe-host"
rm contrib/snmp-probe-host.px
install -d "%{buildroot}%{_mandir}/man1"

find contrib/ -name '*.orig' -delete
find contrib/ -name .gitignore -delete
sed -i 's/env //1' contrib/exec-borg

# plugin list:
echo -n > plugins.lst
for plugin in %{plugins}; do
     for ext in so la; do
     	 echo "%{_libdir}/collectd/${plugin}.${ext}" >> plugins.lst
     done
done

cat <<EOF >README.plugins-all
This package is empty but depends on all collectd plugin subpackages.
EOF

install -d -m 0755 "%{buildroot}%{_sbindir}"
install -D -m0644 contrib/systemd.collectd.service %{buildroot}%{_unitdir}/collectd.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%if 0%?have_strip_nondeterminism > 0
    strip-all-nondeterminism %{buildroot}%{_datadir}/collectd/java/
%endif

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%pre
%service_add_pre %{name}.service

%post
%{fillup_only collectd}
%service_add_post %{name}.service

%post   -n libcollectdclient1 -p /sbin/ldconfig
%postun -n libcollectdclient1 -p /sbin/ldconfig

%files -f plugins.lst
%license COPYING
%doc AUTHORS ChangeLog README.md
%doc contrib
%config(noreplace) %{_sysconfdir}/collectd.conf
%dir %{_sysconfdir}/collectd
%{_bindir}/collectd-tg
%{_bindir}/collectd-nagios
%{_bindir}/collectdctl
%{_bindir}/cussh
%{_sbindir}/collectd
%{_sbindir}/collectdmon
%{_sbindir}/rccollectd
%dir %{_libdir}/collectd
%{_libdir}/collectd/notify_email.so
%{_libdir}/collectd/notify_email.la
%dir %{_datadir}/collectd
%{_datadir}/collectd/types.db
%{perl_vendorlib}/Collectd.pm
%dir %{perl_vendorlib}/Collectd
%{perl_vendorlib}/Collectd/*
%{perl_vendorarch}/auto/Collectd
%{_mandir}/man1/collectd.1%{?ext_man}
%{_mandir}/man1/collectdctl.1%{?ext_man}
%{_mandir}/man1/collectdmon.1%{?ext_man}
%{_mandir}/man1/collectd-tg.1%{?ext_man}
%{_mandir}/man1/collectd-nagios.1%{?ext_man}
%{_mandir}/man1/cussh.1%{?ext_man}
%{_mandir}/man5/collectd.conf.5%{?ext_man}
%{_mandir}/man5/collectd-email.5%{?ext_man}
%{_mandir}/man5/collectd-exec.5%{?ext_man}
%{_mandir}/man5/collectd-perl.5%{?ext_man}
%{_mandir}/man5/collectd-threshold.5%{?ext_man}
%{_mandir}/man5/collectd-unixsock.5%{?ext_man}
%{_mandir}/man5/types.db.5%{?ext_man}
%doc %{perl_man3dir}/Collectd::Unixsock.%{perl_man3ext}%{ext_man}
%dir %{_localstatedir}/lib/collectd
%{_unitdir}/collectd.service

%files web
%config(noreplace) %{_sysconfdir}/apache2/conf.d/%{name}.conf
%dir %{_sysconfdir}/collectd
%config(noreplace) %{_sysconfdir}/collectd/collection.conf
/srv/www/collectd

%files web-js
%doc _rpmdoc_/web-js/README
%config(noreplace) %{_sysconfdir}/apache2/conf.d/%{name}-js.conf
%dir %{_sysconfdir}/collectd
%config(noreplace) %{_sysconfdir}/collectd/collection-js.conf
/srv/www/collectd-js
%{_libexecdir}/collectd-js

%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
%files plugin-amqp
%{_libdir}/collectd/amqp.so
%{_libdir}/collectd/amqp.la
%endif

%if %{with epics}
%files plugin-epics
%{_libdir}/collectd/epics.so
%{_libdir}/collectd/epics.la
%endif

%files plugin-notify-desktop
%{_libdir}/collectd/notify_desktop.so
%{_libdir}/collectd/notify_desktop.la

%files plugin-ipmi
%{_libdir}/collectd/ipmi.so
%{_libdir}/collectd/ipmi.la

%files plugin-snmp
%doc _rpmdoc_/snmp/*
%{_bindir}/collectd-snmp-probe-host
%{_mandir}/man1/collectd-snmp-probe-host.1%{?ext_man}
%{_libdir}/collectd/snmp*.so
%{_libdir}/collectd/snmp*.la
%{_mandir}/man5/collectd-snmp.5%{?ext_man}

%files plugin-pinba
%{_libdir}/collectd/pinba.so
%{_libdir}/collectd/pinba.la

%files plugin-mysql
%{_libdir}/collectd/mysql.so
%{_libdir}/collectd/mysql.la

%files plugin-pcie
%{_libdir}/collectd/pcie_errors.so
%{_libdir}/collectd/pcie_errors.la

%files plugin-postgresql
%{_libdir}/collectd/postgresql.so
%{_libdir}/collectd/postgresql.la
%config %{_datadir}/collectd/postgresql_default.conf

%files plugin-python3
%{_libdir}/collectd/python.so
%{_libdir}/collectd/python.la
%{_mandir}/man5/collectd-python.5%{?ext_man}

%files plugin-java
%doc _rpmdoc_/java/GenericJMX.conf
%{_libdir}/collectd/java.so
%{_libdir}/collectd/java.la
%{_datadir}/collectd/java
%{_mandir}/man5/collectd-java.5%{?ext_man}

%files plugin-virt
%{_libdir}/collectd/virt.so
%{_libdir}/collectd/virt.la

%files plugin-dbi
%{_libdir}/collectd/dbi.so
%{_libdir}/collectd/dbi.la

%files plugin-memcachec
%{_libdir}/collectd/memcachec.so
%{_libdir}/collectd/memcachec.la

%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150400
%files plugin-modbus
%{_libdir}/collectd/modbus.so
%{_libdir}/collectd/modbus.la
%endif

%if 0%{?is_opensuse}
%files plugin-mqtt
%{_libdir}/collectd/mqtt.so
%{_libdir}/collectd/mqtt.la
%endif

%if 0%{?sle_version} < 150000 || 0%{?is_opensuse}
%files plugin-sigrok
%{_libdir}/collectd/sigrok.so
%{_libdir}/collectd/sigrok.la

%files plugin-gps
%{_libdir}/collectd/gps.so
%{_libdir}/collectd/gps.la

%endif

%files plugin-smart
%{_libdir}/collectd/smart.so
%{_libdir}/collectd/smart.la

%files plugin-lua
%{_libdir}/collectd/lua.so
%{_libdir}/collectd/lua.la
%{_mandir}/man5/collectd-lua.5%{?ext_man}

%files plugin-openldap
%{_libdir}/collectd/openldap.so
%{_libdir}/collectd/openldap.la

%files plugin-mcelog
%{_libdir}/collectd/mcelog.so
%{_libdir}/collectd/mcelog.la

%files plugin-ovs
%{_libdir}/collectd/ovs_*.so
%{_libdir}/collectd/ovs_*.la

%files plugin-synproxy
%{_libdir}/collectd/synproxy.so
%{_libdir}/collectd/synproxy.la

%files plugin-write_stackdriver
%{_libdir}/collectd/write_stackdriver.so
%{_libdir}/collectd/write_stackdriver.la

%files plugin-write_syslog
%{_libdir}/collectd/write_syslog.so
%{_libdir}/collectd/write_syslog.la

%files plugin-uptime
%{_libdir}/collectd/check_uptime.la
%{_libdir}/collectd/check_uptime.so

%files plugin-connectivity
%{_libdir}/collectd/connectivity.la
%{_libdir}/collectd/connectivity.so

%files plugin-procevent
%{_libdir}/collectd/procevent.la
%{_libdir}/collectd/procevent.so

%files plugin-sysevent
%{_libdir}/collectd/sysevent.la
%{_libdir}/collectd/sysevent.so

%files plugin-buddyinfo
%{_libdir}/collectd/buddyinfo.la
%{_libdir}/collectd/buddyinfo.so

%files plugin-logparser
%{_libdir}/collectd/logparser.la
%{_libdir}/collectd/logparser.so

%files plugin-ubi
%{_libdir}/collectd/ubi.la
%{_libdir}/collectd/ubi.so

%files plugin-write_influxdb_udp
%{_libdir}/collectd/write_influxdb_udp.la
%{_libdir}/collectd/write_influxdb_udp.so

%if %{with nut}
%files plugin-nut
%{_libdir}/collectd/nut.so
%{_libdir}/collectd/nut.la
%endif

%files spamassassin
%dir %{_datadir}/spamassassin
%config(noreplace) %{_datadir}/spamassassin/99_%{name}.cf
%dir %{perl_vendorlib}/Mail
%dir %{perl_vendorlib}/Mail/SpamAssassin
%dir %{perl_vendorlib}/Mail/SpamAssassin/Plugin
%{perl_vendorlib}/Mail/SpamAssassin/Plugin/Collectd.pm
%doc %{perl_man3dir}/Mail::SpamAssassin::Plugin::Collectd.%{perl_man3ext}%{ext_man}

%files plugin-dpdk
%if %{with dpdk}
%{_libdir}/collectd/dpdkevents.la
%{_libdir}/collectd/dpdkevents.so
%{_libdir}/collectd/dpdkstat.la
%{_libdir}/collectd/dpdkstat.so
%endif
%{_libdir}/collectd/dpdk_telemetry.la
%{_libdir}/collectd/dpdk_telemetry.so

%files plugins-all
%doc README.plugins-all

%files -n libcollectdclient1
%{_libdir}/libcollectdclient.so.1
%{_libdir}/libcollectdclient.so.1.*.*

%files -n libcollectdclient-devel
%{_includedir}/collectd
%{_libdir}/libcollectdclient.so
%{_libdir}/pkgconfig/libcollectdclient.pc

%changelog
* Wed Dec 18 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Normalize jar mtimes for reproducible builds (boo#1134568)
* Tue Dec 17 2024 Matwey Kornilov <matwey.kornilov@gmail.com>
- Add epics plugin
* Sat Dec 14 2024 matwey.kornilov@gmail.com
- Update to version 5.12.0.348.g93f9bdcb:
  * add MariaDB to README
  * Update README.md (#4318)
  * perl: fix compile on clang by ignoring a warning
  * intel_rdt: removed ifdefs
  * bind: fix warning for variable used only in DEBUG() calls
  * intel_rdt: Use pqos_mon_get_value api to obtain event values
  * intel_rdt: corrected returned value for llc_miss mertic
  * intel_rdt: Updated list of supported RDT events
  * intel_rdt: corrected reported value for llc_ref mertic
  * intel_rdt: corrected reported value for llc_miss mertic
  * intel_rdt: corrected reported value name
  * intel_rdt: added support for LLC misses monitoring event
  * lua: add missing test case for #3779, #4235
  * memory.c: workaround to let ValuesPercentage works again without "available"
  * epics: Fix potential deadlock in handle_label_event
  * ras plugin: Ensure each log message prints an appropriate prefix.
  * ras plugin: Use `sysconf(_SC_NPROCESSORS_CONF)` instead of `get_nprocs_conf()`.
  * FreeBSD's PF has a new interface so leverage libpfctl to access it so the right interface is used depending on the version
  * ras plugin: Remove unnecessary includes.
  * .github/workflows/release.yml: Import changes from `collectd-6.0`.
  * version-gen.sh: Add the `--tags` flag to `git describe`.
  * Add GitHub Action to automatically build and upload release assets.
  * ci: Remove the "statgrab" task from CirrusCI.
  * .cirrus.yml: Rename `checks_script` to `make_distcheck_script`.
  * .cirrus.yml: Upload `.log` files as artifacts.
  * write_redis plugin: Clean up allocated fields in `wr_config_free()`.
  * disk.c: add config options to support diskstats 15-20 in KERNEL_LINUX
  * interface plugin: Reorder implementations to put kstat above getifaddrs.
  * configure.ac: fix grpc build
  * disk plugin: Build `disk_submit_single` on Linux only.
  * disk: add /proc/diskstats fields 15 to 20 in KERNEL_LINUX
  * docs/CONTRIBUTING.md: Change formulation examples to discourage verbatim copying.
  * docs/CONTRIBUTING.md: Replace remaining use of "Unlisted Change".
  * docs/CONTRIBUTING.md: Document that PRs with features and fixes should be split.
  * docs/CONTRIBUTING.md: Rename "Unlisted Change" to "Maintenance".
  * write_riemann_threshold.c: fix switch-case fall through warning
  * Pass strcmp() to c_avl_create() as function pointer, not data one
  * turbostat, format_json: Satisfy clang-format CI check
  * Fix signedness mismatch GCC warnings in few of the plugins
  * daemon/utils_cache: remove unused functions and function args
  * Remove unused function arguments from few of the plugins
  * Attribute unused function args as such in few of the plugins
  * write_prometheus: annotate unused args and fix comments
  * format_json, network_parse: annotate unused args as unused
  * docs/CONTRIBUTING.md: Rename "Bug" to "Fix"; improve wording.
  * lua: update explanation about register_notification callback
  * lua: add missing notification callback
  * docs: Document important labels and how to interact with them.
  * .github/workflows/distcheck.yml: Run on Debian12 (current stable).
  * write_riemann plugin: Terminate `riemann_event_set` arguments with `RIEMANN_EVENT_FIELD_NONE`.
  * .cirrus.yml: Provide expected plugin list to `check-built-plugins.sh` if present.
  * .cirrus.yml: Rename container images.
  * .github/workflows/build.yml: Add "Check expected plugins" to "experimental".
  * .github/workflows/build.yml: Add a "Check expected plugins" step.
  * .github/workflows/: Rename container images.
  * .github/workflows/build.yml: Remove Ubuntu Bionic.
  * lua: Add functions to register some missing callbacks
  * lua: Use a global lock to call Lua's API
  * Initial implementation for epics plugin
  * lua: add fallback to detect LuaJIT
  * collection3: Fix inappropriate usage of CGI:param
  * common: Use `sstrncpy` to get around misinformed compiler error.
  * common: Fix compiler warning in unit test.
  * contrib/format.sh src/utils/common/common_test.c
  * cmds: Add a test for `cmd_parse_putval`.
  * cmds: Prevent `cmd_parse_putval` from modifying its `argv` argument.
  * common: Change `parse_values` so it doesn't modify the parsed string.
  * MySQL plugin: Fix incorrect WSREP/Galera metric types.
  * evaluate flush condition with oldest value in the buffer
  * Makefile.am: Build `test_virt_plugin` with the same `CFLAGS` as the *virt plugin*.
  * configure: Use `elif` instead of two separate `if` blocks.
  * configure: Improve the reporting when the "virt" plugin cannot be built.
  * procevent plugin: Consistently mention the unit in log message.
  * procevent plugin: Reference buffer sizing guideline.
  * write_log plugin: remove the "write_log values:" line when logging metrics.
  * procevent plugin: report errors in human readable form.
  * procevent plugin: ensure the ring buffer length is not zero.
  * procevent plugin: remove use of a nested flexible array member.
  * Build workflow: request that clang produce DWARF v4 debug symbols.
  * Disable "exit on error" when running `make check`.
  * procevent plugin: Disable the `-Wgnu-variable-sized-type-not-at-end` warning.
  * .cirrus.yml: Update list of compilers to match the `debian_unstable` container.
  * Build workflow: add builds for `--enable-debug` and `CC=clang`.
  * Workflows: rename "sid_amd64" to "debian_sid".
  * .cirrus.yml: Report failures from CentOS 9 and Fedora 39.
  * .cirrus.yml: Fix reporting of test failure.
  * .cirrus.yml: set parallelism to number of CPUs.
  * .cirrus.yml: Add task for FreeBSD builds.
  * .cirrus.yml: remove obsolete platforms, add recent ones.
  * .cirrus.yml: s/master/main/
  * NUT plugin: import `<time.h>` before `<upsclient.h>`.
  * gmond plugin: Improve `mc_handle_metadata_msg()`.
  * gmond plugin: Look for RPC headers in /usr/include/tirpc.
  * gmond plugin: Import `<ganglia.h>`.
  * Workflow build: upload `config.log` and other log files.
  * Notify upstart/systemd after initialization is complete.
  * SMART plugin: initialize struct passed to `ioctl(2)`.
  * Netlink plugin: complete initialize structs used for testing.
  * Build workflow: report the status of `make check` after the test log has been uploaded.
  * Build workflow: use all available CPUs.
  * Build workflow: Add Fedora 38 and 39, remove Fedora 36.
  * ./contrib/format.sh src/amqp.c
  * Update README.md
  * Add Ubuntu 22.04 ("Jammy Jellyfish") and Ubuntu 23.10 ("Mantic Minotaur").
  * Build workflow: also remove EL8 (based on CentOS 8).
  * Build workflow: remove old distros.
  * AMQP plugin: prefer the `rabbitmq-c/amqp.h` header if available.
  * Fix compile warning for amqp
  * Intel RDT plugin: use `pqos_mon_start_cores()` if available.
  * Intel RDT plugin: use `pqos_mon_start_pids2()` if available.
  * Python plugin: use `PyConfig` to set argv.
  * Write MongoDB plugin: fix format trunction errors.
  * Give the action and job better names.
  * Remove `make distcheck` from the regular "build" action.
  * Distcheck action: use Debian 11 ("Bullseye") for now.
  * Add new GitHub action for running `make distcheck`.
  * curl_stats: fix compatibility with new versions of cURL.
  * Build workflow: add Debian 12 ("Bookworm") and remove Debian 9 ("Stretch").
  * Add Valgrind suppression for libvirt memory leak.
  * Intel RDT: fix compilation with libpqos < 4.4.
  * Revert "GitHub actions: upgrade to actions/checkout@v4"
  * GitHub actions: upgrade to actions/checkout@v4
  * GitHub actions: include job name in artifact name.
  * GitHub actions: continue on error and upload test logs.
  * clang format
  * Compare both PID and process start time to avoid issues with immediate PID reuse on Linux platform.
  * write_prometheus: don't use AI_ADDRCONFIG for resolving bind address
  * Convert src/collectdctl.pod to UTF-8.
  * Add .md to README in redhat specfile
  * Put README(.md) back in the dist
  * Ensure %%perl_vendorlib in redhat specfile
  * Update IPTables plugin build-dep in redhat specfile
  * Add RAS plugin to redhat specfile
  * Add MMC plugin to redhat specfile
  * Removed extra call to swap_submit_usage.
  * Update README.md
  * Update contrib/postgresql/README.md
  * Update contrib/postgresql/README.md
  * Update contrib/postgresql/README.md
  * contrib/postgresql: Second postgresql database layout.
  * intel_rdt: added support for LLC references monitoring event
  * intel_rdt: start only supported events
  * add questions metric for mysql plugin
  * plugin processes: fix doc typo
  * Change AMQP queue drops from DEBUG to WARNING
  * vmem: add metrics starting with `pgrefill`
  * 3052: Renamed README to README.md and added TOC.
  * processes: format array size def in read fork_rate & ctxt
  * processes: fix prints & remove useless comments
  * processes: simpler illustration in conf.pod
  * processes: eliminate hardcoded arraysize in read ctxt & fork_rate
  * processes: determine if ctxt is enabled before read_sys_ctxt_switch
  * processes: format `/proc/stat` WARNING & ERROR
  * processes: use buffer to read /proc/stat once according to procs_running
  * processes: remove running++ since we calc it in procs_running later
  * processes: make contextswitches configurable
  * Running contrib/format.sh.
  * Pass precise size of struct sockaddr, whichever type of struct sockaddr, to getnameinfo() on NetBSD.
  * cpufreq: init max_avail_freqs with 128
  * cpufreq: dynamically alloc max_avail_freqs according to time_in_state
  * cpufreq: format.sh cpufreq.c
  * cpufreq: make MAX_AVAIL_FREQS configurable in conf
  * Fix glibc feature macro handling for timegm
  * vmem: add "scan" metrics starting with "pgscan_"
  * vmem: add "pgscan_"
  * vmem: add metrics start with "pgscan_" in Kernel Linux
  * Fix a memory leak in the `write_stackdriver` plugin
* Sat Mar 11 2023 suse+build@de-korte.org
- Update to version 5.12.0.134.g4cebbfc:
  * Hugepages plugin skips reading write-only file
  * Update the format of contrib/snmp-data.conf
  * [cleanup] Fix typo in comment and remove executable bits of config file
  * Remove upstreamed patch
  - Fix-compile-issue-if-net-snmp-has-NETSNMP_DISABLE_MD5-set.patch
- Change to %%bcond style conditional builds
- Disable building NUT plugin in Tumbleweed (fails to build due to changes
  in NUT-2.8.0)
- Minor spec file fixes
* Tue Jan 31 2023 trenn@suse.de
- Update to version 5.12.0.130.g2f3c12e:
  * Fix formatting in mdadm events table
  * Add new exec-borg script to contrib/
  * ChangeLog: v5.12 milestone: Fix issue #3127
  * use derive_t instead of int inside ovs_stats_get_port_stat_value
  * In macOS 12, `IOMasterPort` is deprecated in favor of `IOMainPort`
  * - allow alertmanager correlation and resolve - fix meta names with ':'
  * fix drop probability
  * add config option to write metadata
- Fix build issue if net-snmp has NETSNMP_DISABLE_MD5 set:
  A Fix-compile-issue-if-net-snmp-has-NETSNMP_DISABLE_MD5-set.patch
- Use autosetup and adopt patches from -p0 to -p1:
  M    collectd-fix-config.patch
  M    collectd-fix_spamassassin_doc.patch
- Use obs_scm and others in _service file:
  A    _service
  A    _servicedata
  A    collectd.obsinfo
* Wed Feb 16 2022 Thomas Renninger <trenn@suse.de>
- Add (Build)Requirements for these plugins (jsc#SLE-23472):
  - dpdkevents
  - dpdkstat
  - dpdk_telemetry
  and build a new collected-plugin-dpdk rpm for them
- Enable and add intel_rdt and capabilities to general plugin rpm
- Remove an old configure paramter:
  configure: WARNING: unrecognized options: --without-included-ltdl
* Thu Sep 16 2021 Matwey Kornilov <matwey.kornilov@gmail.com>
- Fix version mess introduced in previous changes.
  + rabbitmq-c package is available since SLES 15 SP3
    so amqp plugin can be enabled for Tumbleweed or Leap 15.3+
  + libmodbus package is available in SLES 15 SP4 Backports
    so modbus plugin can be enabled for Tumbleweed or Leap 15.4+
* Wed Sep  8 2021 Matwey Kornilov <matwey.kornilov@gmail.com>
- add amqp plugin
* Wed Sep  1 2021 Christian Vögl <christian.voegl@suse.com>
- Disabled the mqtt plugin for SLES and the modbus plugin for
  everything except Tumpleweed as the dependencies are not met in
  those distributions
- Added the modbus plugin as dependency to plugins-all
* Mon Aug 30 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Added patch(es):
  * harden_collectd.service.patch
* Mon Jun 28 2021 Matwey Kornilov <matwey.kornilov@gmail.com>
- add modbus plugin
* Tue Feb 23 2021 Reinhard Max <max@suse.com>
- The bind plugin does not need bind-devel.
* Sun Dec 20 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- add mqtt plugin
* Wed Sep 23 2020 Dirk Mueller <dmueller@suse.com>
- update to 5.12.0:
  * varnish plugin: Added varnish 6 support.
  * amqp1 plugin: New options to limit send queue length has been added.
  * mdevents plugin: New plugin to generate notifications about events
  * amqp plugin: Updated option to allow multiple hosts to support
    failover.
  * mysql plugin: Reporting of the fields Slave_IO_Running and
    Slave_SQL_Running has been added.
  * write_http plugin: libcurl default HTTP response has been moved to a
    buffer instead of stdout.
  * disk plugin: Provided an udev rule with ID_SERIAL based attribute so
    disk and partition data don't get mixed incorrectly in udev-based disk
    naming.
  * swap plugin: Implementation for NetBSD has been added.
  * netstat_udp plugin: New plugin ((currently NetBSD-only) to report UDP
    summary statistics has been aded.
  * smart plugin: SMART plugin has been extended with NVMe device
    functionality.
  * infiniband plugin: New plugin to collect metrics about IB ports has
    been added.
  * snmp plugin: Count option was added allowing to gather the number of
    table entries (matching given criteria) rather than their values.
  * cpu plugin: Implementation for NetBSD has been added.
  * irq plugin: Implementation for NetBSD has been added.
  * processes plugin: Implementation for NetBSD has been added.
  * entropy plugin: Implementation for NetBSD has been added.
  * netlink plugin: VFs statistics and link info has been added.
  * memory plugin: Implementation for NetBSD has been added.
  * curl_jolokia plugin: New plugin has been added to integrate jolokia to
    fetch jmx counters via HTTP/json. Thanks to Wilfried Goesgens. #2470
  * write_sensu plugin: IncludeSource option has been added.
  * intel_pmu plugin: Check for libjevents version has been improved.
  * python plugin: Error-handling code of PyType_Ready has been added.
  * collectd: Updated specfile for EL8. Thanks to Fabien Wernli. #3346
  * openvpn plugin: Parsing of empty fields has been fixed.
  * dpdk_telemetry plugin: Build issues has been fixed.
  * mqtt plugin: A problem with stuck after 20 (qos=1) messages has been
    fixed.
  * varnish plugin: Target in category for varnish 6 has been added.
  * mqtt plugin: Resubscribe after a reconnect. Thanks to Maciej
  * zookeeper plugin: Missing 3.5 mntr fields has been added. Thanks to
  * sensors plugin: The documentation has been improved. Thanks to Florian
  * types.db(5): Documentation of metric definitions has been improved.
  * intel_pmu plugin: The possible crash on plugin init has been fixed.
  * processes plugin: Size of reading buffer for /proc/stat has been
  * ubi plugin: Data source type has been fixed from counter to gauge.
  * intelrdt plugin: NaN values in csv output has been fixed. Thanks to
  * capabilities plugin: Conditionalized return type for microhttpd
* Thu Jun 25 2020 Christian Vögl <christian.voegl@suse.com>
- Update to 5.11
  * Adds buddyinfo, logparser, ubi, and write_influxdb_udp plugins
  * Remove lvm plugin
  * Multiple bugfixes/improvements
- update collectd-fix_collection_cgi.patch
* Wed Jan 29 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Cleanup BuildRequires that are not actually in use:
  pkgconfig(devmapper),  pkgconfig(freetype2), pkgconfig(gail),
  pkgconfig(gdk-2.0),  pkgconfig(gtk+-2.0), pkgconfig(libart-2.0).
* Mon Nov 25 2019 Christian Vögl <cvoegl@suse.de>
- Update to 5.10.0 (jsc#SLE-9892)
  * turbostat plugin: Power metrics update for recent server CPUs. Thanks
    to Chris MacNamara. #3276
  * turbostat plugin: Fix warnings generated by the turbostat plugin.
    Thanks to Ryan Mccabe. #3340
  * ZFS ARC plugin: New cache values are now read on Linux. Thanks to
    Jan-Philipp Litza. #3247, #2843
  * connectivity plugin: monitor the network interface up/down status via
    the netlink library. Thanks to Andrew Bays. #2622
  * sysevent plugin: A new plugin that monitors rsyslog for system events.
    Thanks to Andrew Bays. #2624
  * procevent plugin: A new plugin that monitors process starts/stops via
    netlink library. Thanks to Andrew Bays. #2623
  * daemon: Check if plugin actually loaded before reporting configuration
    issues. Thanks to Pavel Rochnyak. #3217
  * daemon: Recover setlocale() call in src/daemon/collectd.c do_init().
    Thanks to Pavel Rochnyak. #3181, #3214
  * Build System: Only include <sys/sysctl.h> when needed. Thanks to Ruben
    Kerkhof. #3298
  * Build System: Link to libnsl.so if needed for inet_ntop(). Thanks to
    Dagobert Michelsen. #3291
  * Build System: Remove double "without" added by commit b781871. Thanks
    to Fabrice Fontaine. #3261
  * Build System: fix compile time issues. Thanks to Matthias Runge.
    [#3179], #3242, #3245
  * Build System: Fix activation of snmp_agent. Thanks to Fabrice
    Fontaine. #3241
  * Build System: Fix bug that leads to CPPFLAGS gets overridden with
    CFLAGS when libxmms is enabled. Thanks to Dagobert Michelsen. #3207
  * perl module: Collectd::Plugins::Openvz: Fix indentation of some
    closing curlies. Thanks to Christian Bartolomäus. #3239
  * tree-wide: Fix a few issues found with LGTM. Thanks to Ruben Kerkhof.
    [#3252]
  * tree-wide: fix ssnprintf wrapper. Thanks to Fabien Wernli.
    [#3237], #3232, #3235, #3236
  * tree-wide: Fix make check. Thanks to Ruben Kerkhof. #3306
  * CI System: Travis: switch to Bionic. Thanks to Ruben Kerkhof. #3307
  * CI System: Travis improvements for MacOS. Thanks to Ruben Kerkhof.
    [#3308]
  * MySQL plugin: Minor documentation improvements. Thanks to Christian
    Bartolomäus. #3288
  * Java plugin: Fix typo in an error message. Thanks to Matthias Runge.
    [#3285], #3286
  * sysevent plugin: Add a few missing calloc result checks in the
    sysevent_init function. Thanks to Andrew Bays. #3282
  * ZFS ARC plugin: A bug that caused the first to values to be skipped
    was fixed. Thanks to Jan-Philipp Litza. #3246
  * SysLog plugin: restore previous behaviour: fallback to info for
    unsupported level. Thanks to Fabien Wernli. #3236, #3238
  * virt plugin: Fix memory leak with libvirt MetadataXPath enabled.
    Thanks to Pavel Rochnyak. #3225, #3228
  * GPU NVidia plugin: Fix build of the plugin. Thanks to Ruben Kerkhof.
    [#3320]
- Changes from 5.9.2:
  * syslog plugin: Don't fail if syslog loglevel doesn't match. Thanks to
    Fabien Wernli. #3236 #3238
  * collectd: Fix ssnprintf wrapper. Thanks to Fabien Wernli. #3237
  * rdt plugin: Fix compile time issues. Thanks to Matthias Runge. #3245
- Changes from 5.9.1:
  * collectd: regex match: Fix unexpected match with empty meta data .
    Thanks to Takuro Ashie. #3178
  * collectd: Fix return value or loglevel for several plugins. Thanks to
    Fabien Wernli. #3182
  * collectd: Add standard include early or _FILE_OFFSET_BITS will have
    definition … . Thanks to Dagobert Michelsen. #3193
  * collectd: Use GCC-specific flags only when compiling with GCC. Thanks
    to Dagobert Michelsen. #3195
  * Use test_utils_proc_pids only when compiling the plugin that uses it.
    Thanks to Dagobert Michelsen. #3197
  * DNS plugin: Do not use headers from glibc. Thanks to Pavel Rochnyak.
    [#3156], #3145
  * collectd: Add missing definitions for libnetsnmpagent. Thanks to
    Dagobert Michelsen. #3203
  * collectd: Move Makefile rules for pid_test inside conditional for
    code. Thanks to Dagobert Michelsen. #3206
  * collectd: Recover setlocale() call in src/daemon/collectd.c do_init().
    Thanks to Pavel Rochnyak. #3214, #3181
  * collectd: Add snprintf wrapper for GCC 8.2/3. Thanks to zebity. #3153,
    [#2895], #3038
  * collectd: Fix bug that leads to CPPFLAGS gets overridden with CFLAGS
    when libxmms is enabled. Thanks to Dagobert Michelsen. #3207
  * Write_Riemann plugin: Copy MetaData to Riemann events in
    write_riemann. Thanks to Romain Tartière. #3158
  * virt plugin: Fix memory leak with libvirt MetadataXPath enabled.
    Thanks to Pavel Rochnyak. #3225, #3230
-Disabled Plugins due to missing dependencies:
  * lvm on Factory, Tumbleweed, Leap15.2 and SLES_15-SP2
  * gps and sigrok on SLES_15 and later
-Removed libstatgrab from buildrequires: only needed for non-Linux systems.
-Rebased patch 9e36cd85a2bb_sigrok_Update_to_support_libsigrok_0_4.patch
-Add new subpackages:
  * plugin-sysevent
  * plugin-procevent
  * plugin-uptime
  - ------------------------------------------------------------------
* Thu Jun 13 2019 Martin Hauke <mardnh@gmx.de>
- Update to 5.9.0:
  * collectd: A new "UNKNOWN" state as the initial state of metrics has
    been added.
  * collectd: config parser: Improved error reporting on global options.
  * collectd: daemon: make plugin_dispatch_multivalue() obey write queue
    limits.
  * collectd: Macros "STRERROR" and "STRERRNO" have been added.
  * collectd: Plugin name field has been added to plugin context to
    improve error reporting.
  * collectd-tg: Use "CLOCK_REALTIME" for collectd-tg times.
  * AMPQ1 plugin: A new plugin to write to amqp1 protocol.
  * Chrony plugin: Ignoring late responses has been added.
  * CPUFreq plugin: Read number of p-state transitions and time spent in
    each p-state.
  * cURL, cURL-XML plugins: Option "Interval" has been added.
  * Exec plugin: Dynamic allocation of grname buffer has been added.
  * GPU NVML plugin: New plugin to collect NVIDIA GPU stats.
  * gRPC plugin: The "VerifyPeer" option for servers has been added.
  * Intel RDT plugin: Support for groups of PIDs has been added.
  * IPMI plugin: Config options "SELSensor" and "SELIgnoreSelected" have
    been added.
  * Modbus plugin: Support for 64 bit vals has been added, support for
    CDAB endian 32-bit modbus polls has been added.
  * Modbus plugin: The "Scale" and "Shift" metrics have been added.
  * Netlink plugin: Handle new counter from Linux kernel version 4.6+.
  * Network plugin: Option "BindAddress" has been added.
  * Ping plugin: An "AddressFamily" configuration option has been added.
  * OVS Stats plugin: Extended metrics "ovs-dpdk" have been added.
  * OVS Stats plugin: Support of bond interface and a "InterfaceStats"
    config option have been added.
  * PCIe Errors plugin: New plugin to read "PCIe" errors.
  * Processes plugin: Support for Linux Delay Accounting has been added.
  * Redis plugin: Keyspace "hitratio" metric has been added, metric
    "operations_per_second" has been removed, an option for connecting via
    UNIX socket has been added.
  * RouterOS plugin: Support for temperature and voltage data has been
    added, use MAC-address when Radio-name is missing.
  * RRDCacheD plugin: Time resolution has been improved to microseconds.
  * Sensors plugin: Checks for upper limit of "SENSORS_API_VERSION" have
    been removed, support for libsensors older than 3.0.0 has been
    dropped.
  * SNMP plugin: New options "PluginInstance", "TypeInstance",
    "TypeInstanceOID", "PluginInstanceOID", "FilterOID", "FilterValues"
    and "FilterIgnoreSelected" have been added.
  * SNMP Agent plugin: Multiple key indexes to snmp table and other new
    features have been added, refactoring, coverity scan issues have been
    fixed.
  * Swap plugin: Support for Linux 2.4 has been dropped.
  * Turbostat plugin: Configuration option "RestoreAffinityPolicy" has
    been added.
  * Turbostat plugin: New metrics "P-states", "Turboboost", "Platform
    TDP", "Uncore bus ratio" have been added.
  * Turbostat plugin: Support of reporting GPU power on SKL has been
    added.
  * virt plugin: Allow read "Hostname" from libvirt metadata.
  * virt plugin: Block info statistics for disk devices have been added.
  * Wireless plugin: A "bitrate" metric has been added.
  * Write Graphite, Write Kafka plugins: Support for Graphite 1.1+ tag has
    been added.
  * Write Prometheus plugin: Option "Host" has been added.
  * Write Stackdriver plugin: New plugin to write to Google Stackdriver
    Monitoring.
  * Write Syslog plugin: "write_syslog" plugin writes values lists as
    syslog messages.
  * collectd: collectdmon cannot exit command line options parse loop has
    been fixed.
  * collectd: Include "kstat.h" if available to provide "kstat_ctl_t",
    include "kstat.h" when available.
  * collectd: Parsing option for avoiding making BaseDir has been fixed.
  * collectd: Remove empty "cmd_listval_t" data structure and related
    no-op code.
  * collectd: src/daemon/plugin.c: Refactor plugin_load_file(),
    src/utils_format_json.c: Remove chatty debug messages.
  * collectd: Stop poisoning function in debug mode.
  * collectd: The number of allocations when parsing types.db has been
    reduced.
  * AMQP1 plugin: Potential memory leaks found via scan-build have been
    fixed, a typo in error log message has been fixed, cleanups.
  * Barometer plugin: Support to "libi2c-4.0" has been added.
  * DBI, Oracle, PostgreSQL plugins: Fixes and improvements.
  * Disk plugin: In linux, reset the disk when it disappears from
    "/proc/diskstats".
  * DPDK Events, DPDK Stats plugins: Buffer size for parsing lcores has
    been increased, a deprecation warning has been fixed, runtime config
    file path has been fixed.
  * GPS plugin: Build with gpsd version 3.18 has been fixed.
  * LUA plugin: A memory leak has been fixed.
  * MySQL plugin: Properly cleanup dropped MySQL connections.
  * Netlink plugin: Truncation warnings have been fixed.
  * NFS plugin: Message "Unexpected number of fields for NFSv4 server
    statistics: 62" has been fixed.
  * NFS plugin: Number of fields for "NFSv4" has been fixed.
  * Notify Email plugin: All notification parameters have been included
    into email.
  * NTPd plugin: Don't treat normal peers as refclocks, skip "0.0.0.0"
    hosts in ntpd plugin.
  * OVS Stats plugin: A macro to populate counters list has been added,
    value of "OpenFlow" has been corrected.
  * OVS Stats, OVS Events plugins: utils_ovs: Avoid potential access of
    freed memory, fixes.
  * Processes plugin: Compilation has been fixed when ps_delay() is not
    used.
  * Python plugin: A compilation warning with Python 3.7 has been fixed.
  * Redis plugin: Bugfixes, extended error reporting, persistent
    connections and parallel polling, ability to select db for queries has
    been fixed.
  * RRDTool plugin: Error reporting has been extended.
  * Sensors plugin: Support for humidity sensors has been added.
  * Sensu, OVS Stat, Turbostat, virt, OAuth, Write Prometheus, Intel RDT
    plugins: Compiler warnings have been fixed.
  * virt plugin: Compiler warnings, a segfault in libvirt, typo in error
    messages have been fixed.
  * virt plugin: Optional "virDomainGetCPUStats()" has been removed from
    main flow, cleanup.
  * virt plugin: Tracking of VM state changes has been fixed.
  * Write MongoDB plugin: Plugin dependencies have been fixed.
  * Write Redis plugin: Bug ""max_set_duration" deletes unexpected data"
    has been fixed.
- Drop patches (fixed by upstream):
  * 0001-gps-plugin-fix-build-with-newer-gpsd.patch
  * Removed-checks-for-upper-limit-of-SENSORS_API_VERSION.patch
- Add new subpackages:
  * plugin-pcie
  * plugin-write_stackdriver
  * plugin-write_syslog
* Sun Apr 14 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.8.1:
  * collectd: Fix "BaseDir" option.
  * collectd: improve error handling, check return values.
  * Build System: use "kstat.h", when available.
  * Build System: Out-of-tree builds have been fixed.
  * Configuration: Error handling in the config parsing code has been
    improved.
  * collectd: The core daemon is now completely licensed under the
    MIT license.
  * Build system: Dependency on libltdl has been removed, support for
    libtool 1 has been dropped.
  Check the ChangeLog file for the complete list of changes.
- Add Removed-checks-for-upper-limit-of-SENSORS_API_VERSION.patch
- Add avoid-pg-config.patch to use pkg-config instead of pg_config
- Refresh patches
- Drop Patches:
  * collectd-split_README.patch (merged upstream)
  * collectd-javac_target.patch (doesn't applies)
* Sat Dec 29 2018 mardnh@gmx.de
- Add patch:
  * 0001-gps-plugin-fix-build-with-newer-gpsd.patch
* Thu Jun  7 2018 mardnh@gmx.de
- Fix BuildRequires for collectd-web
- Make apache configuration files compatible with Apache v2.2 and v2.4
* Wed Dec 13 2017 stefan.bruens@rwth-aachen.de
- Buildrequires for gpsd changed, upstream renamed the pkgconfig
  file in gpsd 3.17.
* Fri Sep  8 2017 stefan.bruens@rwth-aachen.de
- Sort list of plugins bundled in main package, add line breaks
- Add BuildRequires for libsigrok and create a sigrok plugin
  subpackage
- Add 9e36cd85a2bb_sigrok_Update_to_support_libsigrok_0_4.patch
  Apply patch conditionally for libsigrok >= 0.4.0, the API
  is different from the libsigrok 0.3.0 API.
* Tue Jun 27 2017 tchvatal@suse.com
- Disable NUT plugin on older distros (broken NUT devel package)
- Make sure we build lvm plugin
- Disable turbostat plugin as it does not work with new kernels
  https://github.com/collectd/collectd/issues/2311
- Version update to 5.7.2:
  * Various small fixes around, notable fix for CVE-2017-7401
- Update buildrequires to include dependencies not detected by
  configure.ac (like python3)
- Disable Werror
- List all the modules in files and thus stick to --enable-all passed
  to configure to avoid having to name them all
- Switch to python3 from python2 as plugin can be built only once...
- Fix build on Factory
- Remove unused collectd-pthread.pc SOURCE file as it does not
  need to be done anymore
* Tue Jun 27 2017 tchvatal@suse.com
- Remove all the always true conditionals for readability
- Convert to pkgconfig style dependencies
- Remove never applied patch collectd-pkgconfig_libnotify_add_gtk.patch
* Thu Jun 22 2017 tchvatal@suse.com
- Disable libdb collectd integration as we would like to reduce
  libdb exposure everywhere. There are other db backends in collectd
  anyway
* Thu May 25 2017 jengelh@inai.de
- Trim filler wording from descriptions, resolve orthographic
  errors, and shorten a find–delete call.
* Sat May  6 2017 benoit.monin@gmx.fr
- update to version 5.7.1:
  * collectd: Handling of boolean configuration options has been
    unified. Thanks to Sebastian Harl. #2083, #2098
  * collectd: Reporting of internal statistics has been fixed.
    Thanks to Florian Forster. #2108
  * collectd, various plugins: Bugs and issues reported by
    scan-build and coverity-scan have been fixed. Thanks to Ruben
    Kerkhof and Florian Forster.
  * Build system: Parallel build have been fixed. Thanks to Ruben
    Kerkhof. #2110
  * DPDKStat plugin: Portability issues and a double-close bug have
    been fixed. Thanks to Ruben Kerkhof and Marc Fournier.
  * Intel RDT plugin: A check for the libpqos library version has
    been added. Thanks to Serhiy Pshyk.
  * NetApp plugin: Compilation problems have been corrected. Thanks
    to Florian Forster. #2120
  * Write Prometheus plugin: A memory leak has been fixed. Thanks
    to Ruben Kerkhof.
- additional changes from version 5.7.0
  * Documentation: The Turbostat plugin section has been improved.
    Thanks to Florian Forster
  * Documentation: The semantics of the "TypesDB" option have been
    improved. Thanks to Florian Forster.
  * collectd: A generic interface for parsing the text protocol has
    been added. Thanks to Sebastian Harl. #1749
  * collectd: Threads now get named, making them easier to track
    using tools such as top, ps, etc. Thanks to Manuel Luis
    Sanmartín Rozada and Marc Fournier. #547
  * AMQP plugin, Write Graphite plugin, Write Kafka plugin: The new
    "[Graphite]PreserveSeparator" option allows retaining the
    default dot separator rather than escaping it. Thanks to
    Florian Forster. #419
  * Battery plugin: A StateFS backend for gathering statistics has
    been added. Thanks to Rinigus. #1795
  * CPU plugin: CPU aggregation on AIX was fixed. Thanks to Chao
    Yang. #1957
  * Collectd::Unixsock: Fractional seconds support has been made
    more robust. Thanks to Matthias Bethke. #2052
  * DPDKStat plugin: This new plugin collects DPDK interface
    statistics. Thanks to Maryam Tahhan, Harry van Haaren, Taras
    Chornyi and Kim Jones. #1649
  * gRPC plugin: The "DispatchValues" option has been renamed to
    "PutValues". Thanks to Florian Forster.
  * HDDTemp plugin: The 32 devices limit has been removed. Thanks
    to Benjamin Gilbert. #631
  * Hugepages plugin: This new plugin reports the number of used
    and free hugepages on Linux. Thanks to Jaroslav Safka, Maryam
    Tahhan, Kim Jones and Florian Forster. #1799
  * Intel RDT plugin: This new plugin collects statistics exposed
    by Intel's Resource Director Technology . Thanks to SerhiyX.
    [#1970]
  * memcached plugin: The new "Address" option allows connecting to
    a different server than specified by the "Host" option. Thanks
    to Pavel Rochnyack. #1975
  * nginx plugin: Support for reporting failed connections has been
    added. Thanks to Pavel Rochnyack. #1609
  * Perl plugin: Significant internal reworking has been made. The
    new "RegisterLegacyFlush" option has been added. Thanks to
    Pavel Rochnyack. #1731
  * PostgreSQL plugin: Timestamps are now RFC 3339-formatted local
    time. Thanks to Igor Peshansky and Dave Cunningham. #1918
  * Processes plugin: Internal performance improvements have been
    made. Thanks to Pavel Rochnyack. #1980, #1981
  * RRDCacheD plugin: The plugin now tries to reconnect upon failed
    operations. Thanks to Sebastian Harl. #1959
  * SpamAssassin: The plugin can now run in Perl's "tainted mode"
    ("-T"). Thanks to Akos Vandra. #1962
  * Tail plugin: Support for calculating latency distribution of
    matching values has been added. Thanks to Pavel Rochnyack and
    Florian Forster. #1700
  * Tail plugin: The new "GaugePersist" option has been added.
    Thanks to Florian Forster. #2015
  * Target:Set, Target:Replace, Match:RegEx: MetaData support has
    been added . Thanks to Igor Peshansky. #1922, #1923, #1930
  * turbostat plugin: The new "LogicalCoreNames" option allows
    switching to per-core naming rather than per-CPU. Thanks to
    Brock Johnson. #2056
  * virt plugin: The new "BlockDeviceFormat" and
    "BlockDeviceFormatBasename" options help controlling the names
    reported for block-device metrics. Thanks to Deyan Chepishev.
    [#2004]
  * Write Graphite plugin: A new "DropDuplicateFields" option has
    been added. Thanks to Michael Leinartas. #1915
  * Write Kafka plugin: The "Key Random" setting has been
    reintroduced. Thanks to Florian Forster. #1977
  * Write Log plugin: Support for formatting output in JSON has
    been added, using the new "Format" configuration option. Thanks
    to Igor Peshansky. #1924
  * Write Prometheus plugin: This new plugin publishes values using
    an embedded HTTP server, in a format compatible with
    Prometheus' collectd_exporter. Thanks to Florian Forster. #1967
- additional changes from version 5.6.2
  * collectd: A compile error on AIX has been fixed: "MSG_DONTWAIT"
    is not available on AIX. Thanks to Chao Yang.
  * collectd: The capability checking has been rewritten to be more
    portable. Thanks to Florian Forster. #2009
  * collectd.conf(5): Various typos have been fixed. Thanks to Marc
    Fournier.
  * collectd-tg: Incorrect usage of "nanosleep()" has been fixed
    which caused the tool to sleep (almost) indefinitely. Thanks to
    Florian Forster.
  * Build system: Detection of the Java environment has been made
    deterministic to allow for reproducible builds. Thanks to Marc
    Fournier. #1523
  * Build system: Detection of the Lua headers has been improved.
    Thanks to Ruben Kerkhof.
  * APC UPS plugin: Unavailable metrics are now skipped instead of
    reported as 0 (zero). Thanks to Florian Forster. #2025
  * Modbus plugin: Build issues on FreeBSD have been fixed. Thanks
    to Florian Forster.
  * OpenVPN plugin: Gracefully handle empty configurations. Thanks
    to Pavel Rochnyack. #1932
  * PowerDNS plugin: The "recursor command" has been fixed so
    PowerDNS can correctly parse all requested fields. Thanks to
    Ruben Kerkhof.
  * Write Graphite and AMQP plugins: A bug that could lead to a
    missing null-termination has been fixed. Thanks to Markus
    Linnala.
  * Write HTTP plugin: A logic error when checking the correctness
    of the data set has been fixed. Thanks to Pavel Rochnyack. #1996
  * Write Kafka plugin: The "Key Random" config option has been
    fixed. Thanks to Florian Forster. #1977
  * Write Kafka plugin: Support for librdkafka 0.9.0 has been
    added. Thanks to Florian Forster.
  * Write Riemann plugin: Build issues on Solaris have been fixed.
    Thanks to Florian Forster.
  * ZFS ARC plugin: A duplicate metric has been removed. Thanks to
    Ruben Kerkhof. #1963
- additional changes from version 5.6.1
  * Build system: Unnecessary linking of the Write Graphite plugin
    with libyajl has been removed. Thanks to Marc Fournier.
    Debian#839771, #1976
  * collectd: A bug in the "FlushInterval" option that caused a
    segmentation fault in the Write HTTP plugin has been fixed.
    Thanks to Florian Forster. #1954
  * Apache plugin: A syntax error has been fixed. Thanks to Florian
    Forster.
  * cURL-JSON plugin: A segmentation fault that occurred when
    handling JSON with unexpected structure has been fixed. Thanks
    to Florian Forster. #1896
  * PostgreSQL plugin: Handling of "NULL" values in the
    "query_plans" and "query_plans_by_table" queries has been
    fixed. Thanks to Bernd Zeimetz. #1905
  * RRDCacheD plugin: Reconnection behavior has been added. Thanks
    to Sebastian Harl. Debian#657877
  * VServer plugin: Use of a deprecated API ("readdir_r()") has
    been fixed. Thanks to Sebastian Harl.
  * Write Graphite plugin: Make default values configurable at
    compile time again. Thanks to Florian Forster. #1953
  * Write HTTP plugin: A bug has been fixed that lead to flush
    callbacks being registered twice. Thanks to Florian Forster.
    [#1955]
- additional changes from version 5.6.0
  * Build system: An option to to avoid building the DF plugin
    against XFS has been added. Thanks to Ruben Kerkhof. #1878
  * Build system: Autoconf ≥ 2.60, a C99-capable compiler and
    pkg-config are now required. Thanks to Ruben Kerkhof.
  * Build system: Building with "-Werror" is now optional. Thanks
    to Ruben Kerkhof. #1222
  * Build system: Many compilation issues on non-Linux platforms
    have been fixed, leading to wider plugin support. Thanks to
    Ruben Kerkhof, Dagobert Michelsen, Havard Eidnes and Robert
    Viduya.
  * Build system: The configuration summary now also ends up in
    config.log. Thanks to Sebastian Harl.
  * collectd: All command-line options now override global options
    from the config file. Thanks to Sebastian Harl. #366
  * collectd: A number of unit tests for commonly used functions
    have been added. Thanks to Florian Forster.
  * collectd: Plugins start up and read timeouts are now logged.
    Thanks to Marc Fournier. #1293, #1254
  * collectd: Support for a timeout has been added to "FLUSH"
    callbacks. Thanks to Manuel Luis Sanmartín Rozada.
  * collectd: The "-T" command line switch now reports more errors.
    Thanks to Corey Kosak. #1642
  * collectd: The max size of value list elements
    ("DATA_MAX_NAME_LEN") has been doubled and is now configurable
    at build time. Thanks to Amy Lin, Florian Forster and Radu
    Brumariu. #1120
  * Set target: The "MetaData" option has been added. Thanks to
    Yves Mettier and Kevin Bowling. #1106, #1656, #1913
  * AMQP, Write_HTTP, Write_Kafka plugins: Support for libyajl < 2
    has been added. Thanks to Florian Forster.
  * APC UPS plugin: Parsing of end markers has been fixed. Thanks
    to Florian Forster #617
  * APC UPS plugin: The "PersistentConnection" option has been
    added. Thanks to Florian Forster #617
  * ceph, DNS, Exec, IPTables, Ping, turbostat plugins: When
    running unprivileged, these plugins will now warn about
    insuffiscient permissions or capabilities(7). Thanks to Marc
    Fournier. #1530
  * Chrony plugin: This new plugin collects NTP data from the
    chrony NTP server. Thanks to Claudius Zingerli. #1548
  * cpusleep plugin: This new plugin measures time spent by CPU in
    deep sleep mode. Thanks to Rinigus. #1826
  * CPU plugin: The "ReportNumCpu" option has been added. Thanks to
    Fabien Wernli.
  * cURL, cURL-JSON, cURL-XML plugins: The new "Statistics" reports
    various per-HTTP connection timers. Thanks to Sebastian Harl.
    [#1004]
  * DBI plugin: The "Interval" option has been added to "Database"
    blocks. Thanks to Michal Bebjak.
  * Disk plugin: Support for FreeBSD has been added. Thanks to Xin
    Li, Brad Davis, Ruben Kerfhof and Kevin Bowling.
  * Empty Counter match: Support for derives has been implemented.
    Thanks to Florian Forster. #1813
  * GenericJMX plugin: Support for TabularData and the "PluginName"
    option have been added. Thanks to David Crane. #1290, #1291
  * GPS plugin: This new plugin reports the number of sattelites
    seen by and precision of a GPS receiver. Thanks to Nicolas
    Jourden. #1346
  * gRPC plugin: This new client and server plugin allows sending
    and receiving metrics using the gRPC protocol. Comparable to
    the UnixSock plugin, but using TCP and TLS. Thanks to Sebastian
    Harl and Florian Forster.
  * Interface plugin: Reporting dropped packets has been added.
    Thanks to Marc Falzon. #1555
  * Interface plugin: The "ReportInactive" has been added, letting
    users skip inactive network interfaces. Thanks to Rinigus. #1791
  * Interface plugin: The new, Solaris-only "UniqueName" option has
    been added. Thanks to Yoga Ramalingam. #1416
  * Lua plugin: This new language binding allows writing plugins
    using the Lua programming language. Thanks to Julien Ammous,
    Florian Forster and Ruben Kerkhof.
  * Memory plugin: Reporting of ARC memory on Solaris has been
    added. Thanks to Brian ONeill.
  * MQTT plugin: This new plugin sends metrics to and/or receives
    metrics from an MQTT broker. Thanks to Marc Falzon, Jan-Piet
    Mens, Nicholas Humfrey and Florian Forster. #805, #1124
  * MySQL plugin: Connection to the database server can now be done
    over SSL. Thanks to Brian Lalor. #1256
  * MySQL plugin: Monitoring slow queries has been added. Thanks to
    skob. #1773
  * MySQL plugin: mysql_bpool_pages-flushed has been renamed to
    mysql_bpool_counters-pages_flushed because the value is
    cumulative. Thanks to Marek Becka.
  * MySQL plugin: Support for Galera statistics has been added.
    Thanks to Rachid Zarouali. #1849
  * MySQL plugin: Support for InnoDB metrics was improved. Thanks
    to Aman Gupta. #1111
  * MySQL plugin: The "mysql_sort" type has been split into 3
    different types. Thanks to Pavel Rochnyack. #1592
  * Network plugin: Decryption error logging has been improved.
    Thanks to Pavel Rochnyack. #1735
  * Notify Nagios plugin: This new plugin sends notifications to
    Nagios as a passive check result. Thanks to Florian Forster.
  * NTPd plugin: The plugin now detects if the ntp daemon reports
    nanoseconds instead of microseconds. Thanks to Matwey V.
    Kornilov. #1783
  * OpenLDAP plugin: Several connection-related improvements have
    been made. Thanks to Marc Fournier. #1308
  * OpenLDAP plugin: Support for "simple authentication" has been
    added. Thanks to Marek Becka. #1087
  * Ping plugin: The "Size" option has been added, allowing the
    ICMP data payload size to be configured. Thanks to Witold
    Baryluk. #1395
  * PostgreSQL, DBI, Oracle plugins: The new "PluginInstanceFrom"
    option has been added. Thanks to Pavel Rochnyack. #1707
  * PowerDNS plugin: The recursor metrics have been updated to
    3.7.3 and missing rr types have been added. Thanks to Ruben
    Kerkhof.
  * Processes plugin: Counting of context switches was added for
    Linux. Thanks to Manuel Luis Sanmartín Rozada. #1036
  * Processes plugin: Improve reliability of thread counts on
    Linux. Thanks to Manuel Luis Sanmartín Rozada.
  * Python plugin: Minimal Python version requirement has been
    bumped to 2.6. Thanks to Ruben Kerkhof. #1864
  * Redis plugin: Several additional metrics are now collected.
    Thanks to Marc Falzon and Matteo Contrini. #1807, #1483
  * Sensors plugin: The "UseLabels" option has been added. Thanks
    to Christian Fetzer.
  * SMART plugin: The new "IgnoreSleepMode" option has been added.
    Thanks to Scott Talbert. #1770
  * SMART plugin: The new "UseSerial" option allows identifying
    devices in a stable way. Thanks to Scott Talbert. #1794
  * SNMP plugin: The "IpAddress" can now be used for instances.
    Thanks to Vincent Bernat. #1397
  * StatsD plugin: Latency calculation histogram is now able to
    shrink automatically to optimal size. Thanks to Pavel
    Rochnyack. #1622
  * StatsD plugin: The "CounterSum" option has been added. Thanks
    to Florian Forster. #929, #1282, #1311
  * UUID plugin: The plugin now also looks in in smbios system
    table and "/sys/class/dmi". Thanks to Ruben Kerkhof. #1490
  * virt plugin: The "PluginInstanceFormat" option has been added.
    Thanks to Ruben Kerkhof. #1100
  * Write Graphite plugin: The "ReconnectInterval" option has been
    added. Thanks to Toni Moreno and Florian Forster.
  * Write HTTP plugin: A KairosDB formatter has been added. Thanks
    to Aurélien Rougemont. #1809
  * Write HTTP plugin: Notifications are now handled by this
    plugin. Thanks to Florian Forster.
  * Write HTTP plugin: The "LogHttpError" option has been added.
    Thanks to vzubko.
  * Write HTTP plugin: The new "Headers" option allows setting
    custom HTTP headers in outgoing requests. Thanks to Brandon
    Arp. #1634
  * Write Kafka plugin: Key handling has been made more
    comprehensive and reliable. Thanks to Florian Forster,
    Pierre-Yves Ritschard and Vincent Bernat. #1765, #1695, #1393
  * Write Redis plugin: The "Database", "MaxSetSize", "Prefix" and
    "StoreRates" options have been added. Thanks to Brian Kelly and
    Sebastian Pfahl.
  * Write Riemann plugin: The new "BatchFlushTimeout" and "Timeout"
    option have been added. Thanks to Pierre-Yves Ritschard and
    Gergely Nagy.
  * Write Riemann plugin: This plugin now requires the
    riemann-c-client library, version 1.6.0+. This adds support for
    submitting values to Riemann over TLS. Thanks to Gergely Nagy.
    [#986]
  * Write TSDB, Write Sensu, Write Riemann, Write Graphite, Write
    TSDB plugin: TCP keepalive is now enabled, helping graceful
    recovery from unclean network disconnections. Thanks to Marc
    Fournier. #1549
  * XenCPU plugin: This new plugin collects XEN Hypervisor CPU
    stats. Thanks to Pavel Rochnyack. #1608
  * ZFS ARC plugin: Several new statistics have been added and a
    couple of obsolete ones removed. Thanks to Brad Davis, Brian
    ONeill and Ruben Kerkhof.
  * Zone plugin: This new plugin reads per-zone CPU usage on
    Solaris. Thanks to Mathijs Mohlmann and Dagobert Michelsen.
- additional changes from version 5.5.3
  * collectd: Write threads are stopped before shutdown callbacks
    are called. Thanks to Florian Forster. #1110
  * collectd: A compile error on AIX has been fixed: "MSG_DONTWAIT"
    is not available on AIX. Thanks to Chao Yang.
  * libcollectdclient: Lines printed to "STDERR" are now guarded by
    the environment variable "COLLECTD_TRACE". Thanks to Florian
    Forster. #105
  * collectd.conf(5): Various typos have been fixed. Thanks to Marc
    Fournier.
  * Build system: Detection of the Java environment has been made
    deterministic to allow for reproducible builds. Thanks to Marc
    Fournier. #1523
  * APC UPS plugin: Unavailable metrics are now skipped instead of
    reported as 0 (zero). Thanks to Florian Forster. #2025
  * Battery plugin: The minimum value has been removed from the
    power type to allow the plugin to report discharging batteries
    as negative power. Thanks to Florian Forster.
  * DBI, Oracle and PostgreSQL plugins: An error message when the
    type instance is truncated has been added. Thanks to Florian
    Forster. #4
  * cURL-JSON plugin: A possible segmentation fault when parsing
    unexpected JSON has been fixed. Thanks to Florian Forster. #1896
  * DF plugin: Compilation with xfsprogs ≥ 4.7.0 has been fixed.
    Thanks to Thomas Deutschmann. #1877
  * Modbus plugin: Build issues on FreeBSD have been fixed. Thanks
    to Florian Forster.
  * Network plugin: An error message has been corrected. Thanks to
    Florian Forster.
  * Network plugin: Handling of errors form secure memory
    initialization has been improved: the plugin fails gracefully
    now instead of calling "abort()". Thanks to Sebastian Harl.
  * Network plugin: The gcrypt library is only initialized when it
    is actually required due to the network plugin's configuration.
    Thanks to Florian Forster. #1902
  * Ping plugin: The init callback has been changed to be
    idempotent, fixing errors being reported on Solaris. Thanks to
    Florian Forster. #869
  * PostgreSQL plugin: The query_plans and query_plans_by_table
    queries have been improved to return 0 (zero) instead of "NULL"
    when not available. Thanks to Bernd Zeimetz. #1905
  * PowerDNS plugin: The "recursor command" has been fixed so
    PowerDNS can correctly parse all requested fields. Thanks to
    Ruben Kerkhof.
  * Python plugin: Handling of data sets with multiple data sources
    of different type has been fixed. Thanks to Sebastian Harl.
  * RRDCacheD plugin: Reconnection behavior after failed operations
    has been added. Thanks to Sebastian Harl. Debian#657877
  * Write Graphite and AMQP plugins: A bug that could lead to a
    missing null-termination has been fixed. Thanks to Markus
    Linnala.
  * Write Kafka plugin: Support for librdkafka 0.9.0 has been
    added. Thanks to Florian Forster.
  * Write Riemann plugin: Build issues on Solaris have been fixed.
    Thanks to Florian Forster.
- refresh patches:
  * collectd-fix_broken_perl-5.10.patch
  * collectd-split_README.patch
  * collectd-version.patch
- drop patch collectd-5.5.2-exec-no-output.diff: fixed upstream
- remove plugin write_riemann: not built anymore
- add new plugins chrony, cpusleep, hugepages, notify_nagios
- add lua-devel as BuildRequires and create a sub-package for
  the lua plugin
- add gpsd-devel as BuildRequires and create a sub-package for
  the gps plugin
* Sun Oct 30 2016 seife+obs@b1-systems.com
- rebase and rename collectd-5.5.2-exec-no-output.diff
* Sun Aug 14 2016 benoit.monin@gmx.fr
- put the SMART plugin in a separate sub-package
* Sat Aug 13 2016 benoit.monin@gmx.fr
- update to upstream version 5.5.2:
  * collectd: A division by zero has been fixed in the
    "plugin_dispatch_multivalue()" function. Thanks to Corey Kosak.
  * collectd: The address of the Free Software Foundation has been
    fixed in GPL license headers. Thanks to Ruben Kerkhof.
  * Build system: Detection and handling of librrd 1.6 and later
    has been fixed. Thanks to Ruben Kerkof.
  * Apache plugin: A warning about a possible misconfiguration has
    been added. Thanks to Marc Fournier.
  * cURL, cURL-JSON and cURL-XML plugins: A memory leak when
    allocating more memory fails has been fixed. Thanks to Brandon
    Arp.
  * DF plugin: A build issue on DragonFlyBSD has been fixed. Thanks
    to Ruben Kerkhof. #1575
  * Ethstat plugin: Code to strip leading whitespace from device
    names. This works around an issue in the VMXNet3 driver. Thanks
    to Thomas Guthmann. #1059
  * Exec plugin: A problem in the error handling of an fdopen()
    failure has been fixed. Thanks to @ciomaire.
  * Modbus plugin: The debug output has been disabled by default.
    It is now only enabled when building with "--enable-debug".
    Thanks to Eric Sandeen and Marc Fournier.
  * Network plugin: A check for the initialization of secure memory
    has been added. Previously, failure to initialize this memory
    was ignored. Thanks to @yujokang. #1665
  * Network plugin: A heap overflow has been fixed in the server
    code. This issue can be triggered remotely and is potentially
    exploitable. Thanks to Emilien Gaspar. CVE-2016-6254
  * Perl plugin: Init callbacks have been changed to run
    essentially single-threaded to avoid race conditions by init
    functions which create additional threads. Thanks to Pavel
    Rochnyack. #1706
  * Processes plugin: A compilation error on systems without
    "regex.h" has been fixed. Thanks to Corey Kosak.
  * Processes plugin: A memory leak on Solaris has been fixed.
    Thanks to Jim Quinn.
  * Processes plugin: A warning about too long process names has
    been added. Thanks to Marc Fournier. #1284
  * Redis plugin: A memory leak in an error handling code path has
    been fixed. Thanks to Andrés J. Díaz.
  * Redis plugin: The data source type of the expired_keys metric
    has been corrected to "DERIVE". Thanks to Marc Falzon and Marc
    Fournier. #1483.
  * SMART plugin: A build dependency on libudev has been added.
    Thanks to Pavel Rochnyack. #1724
  * StatsD plugin: A deadlock on plugin shutdown has been fixed.
    Thanks to Pavel Rochnyack #1703
  * Write HTTP plugin: Freeing of memory holding HTTP headers
    during shutdown has been fixed. Thanks to Tolga Ceylan.
  * Write Sensu plugin: A segfault when the Tag was unset has been
    fixed. Thanks to Marc Fournier.
  * ZFS ARC plugin: The cache_operation-stolen metric has been
    removed for FreeBSD 10.2 and later. Thanks to Ruben Kerkhof.
    [#1580]
- additional changes from version 5.5.1:
  * Build system: Compilation errors have been avoided by correctly
    defining package name and version used by autoconf. Thanks to
    Nathan Berkley. #1063
  * Build system: Dependency ordering was fixed to ensure parallel
    builds work reliably. Thanks to Gustavo Zacarias. #1125
  * Build system: Error messages have been improved and building
    the unit tests has been fixed on Solaris. Thanks to Florian
    Forster and Dagobert Michelsen. #1077
  * Build system: The move of the "utils_ignorelist" functions has
    been reverted. This fixes build issues of numerous plugins.
    Thanks to Benjamin Drung;. #1323
  * Build system: The fhcount plugin has been restricted to Linux.
    Thanks to Ruben Kerkhof. #1195
  * Build system: Detection of header files for the turbostat
    plugin has been fixed. Thanks to Marc Fournier. #1075
  * collectd: The "LC_NUMERIC" locale is now forced, to prevent
    issues with some plugins on environments using a comma as
    decimal separator. Thanks to Florian Forster. #1237
  * Documentation: Some precisions related to the virt plugin have
    been added. Thanks to Wojtek Bocer and Ruben Kerkhof.
  * Documentation: The CollectdInternalStats documentation has been
    improved. Thanks to Yves Mettier and Florian Forster.
  * Battery plugin: A missing Type has been added. Thanks to Marc
    Fournier. #1338
  * Bind plugin: An off-by-one error has been fixed: an index was
    checked against a wrong variable, which may lead to an
    out-of-bounds read. Thanks to Michal Humpula. #1123
  * Ceph plugin: JSON parsing has been refactored to support ceph
    10.0.0 and fixes several buffer overflows. Thanks to Florian
    Forster. #1350
  * CPU plugin: A Mac OS X specific bug has been fixed: the plugin
    expected an incorrect number of CPU states, resulting in
    failing read callbacks. This regression was introduced in
    5.5.0. Thanks to Robert Viduya.
  * Disk plugin: Support for Mac OS X 10.10 has been added. Thanks
    to Robert Viduya. #1065
  * IPC plugin: Support for building with musl-libc has been added.
    Thanks to Natanael Copa. #1147
  * Log Logstash plugin: A segfault when using libyajl, version 1
    was fixed. Thanks to Vincent Bernat. #1190
  * Log Logstash plugin: The timestamp is now ISO 8601 compliant.
    Thanks to Marc Fournier. #1132
  * memcached plugin: The Type of the listen-disabled metric was
    fixed. Thanks to Florian Forster. #1356
  * MySQL plugin: The Type used by Innodb_buffer_pool_pages_flushed
    was fixed. Thanks to Marek Becka. #1085
  * OpenLDAP plugin: A crash when using LDAPI (LDAP-over-IPC) got
    fixed. Thanks to Marek Becka. #1080
  * OpenLDAP plugin: Support for Mac OS X has been added. Thanks to
    Ruben Kerkhof. #1489
  * SMART plugin: A memory leak has been fixed. Thanks to Florian
    Schüller and Pierre-Yves Ritschard. #1076
  * Swap plugin: A regression that would lead to swap usage being
    reported in kilobytes (instead of bytes) has been fixed. Thanks
    to Marek Becka. #1071
  * Varnish plugin: Support for FreeBSD has been added. Thanks to
    Ruben Kerkhof. #1182
  * Varnish plugin: Support for versions 3 and 4 has been made more
    tolerant to minor changes in Varnish point releases. Thanks to
    Marc Fournier. #1302
  * virt plugin: A copy-and-paste mistake in an error message has
    been fixed. Thanks to Ruben Kerkhof. #1101
  * Write Kafka plugin: Support for Solaris has been added. Thanks
    to Shahul Hameed. #1171
  * Write Redis plugin: Dead code has been removed. Thanks to Brian
    Kelly. #1143
  * 27 patches have been applied to numerous plugins and core
    components, fixing various programming errors which were
    reported by scan-build, libasan, FBInfer, coverity-scan and
    clang: Thanks to Ruben Kerkhof, Florian Forster and Marek
    Becka.
  * Collectd::Unixsock: A Perl error got corrected. Thanks to
    Ciaran Mac An Iomaire. #1295
- update patch collectd-fix_broken_perl-5.10.patch
- drop patch collectd-df-remove-duplicates.patch: fixed upstream
- add libatasmart-devel and libudev-devel as BuildRequires to enable
  the SMART plugin
* Thu Jul  7 2016 joop.boonen@opensuse.org
- Use the correct contrib/systemd.collectd.service in stead of
  contrib/collectd.service this fixes, boo#987462
* Tue Feb 23 2016 dvaleev@suse.com
- Build turbostat plugin only for Intel architectures
* Fri Jan 15 2016 mardnh@gmx.de
- packaging:
  * removed patches:
  - collectd-new_libstatgrab.patch (fixed upstream)
  - collectd-lib64.patch (fixed upstream)
  - collectd-fix_libltdl_autoreconf.patch (fixed upstream)
  * updated patches:
  - collectd-javac_target.patch
  - collectd-version.patch
- upstream update  release 2015-05-27, Version 5.5.0
  * Build system: Ability to make out-of-tree builds has been fixed.
  Thanks to Vincent Bernat. #792
  * Build system, Disk and Users plugins: Detection and use of libstatgrab
  ≧ 0.90 has been added. Thanks to Vincent Bernat. #445, #795, #806,
  [#807], #908
  * Build system, Memory, CPU, TCPConns and Processes plugins: Numerous
  fixes related to OpenBSD support have been added. Thanks to Landry
  Breuil. #777, #778, #779, #808
  * Build system: Plugins now only export "module_register()". Thanks to
  Florian Forster.
  * Build system: Various cleanups and improvements have been done. Thanks
  to Marc Fournier.
  * collectd: Numerous internal changes and improvements to the daemon and
  the plugin API have been make. Thanks to Florian Forster, Pierre-Yves
  Ritschard and Alex Petrov. #512, #727
  * collectd: Numerous spelling mistakes have been corrected in comments
  and documentation and several error messages have been improved.
  Thanks to Ruben Kerkhof, Abhinav Upadhyay, Olivier Bazoud, Pierre-Yves
  Ritschard, Tim Smith, Moshe Zada, Katelyn Perry and Marc Fournier.
  * collectd: Rules/Targets can now be appended to existing Filter Chains.
  Thanks to Marc Falzon. #444
  * collectd: Failing Filter Chains destinations will now log the list of
  available write targets. Thanks to Wilfried Goesgens. #650, #1043
  * collectd: Support for process signaling and management by upstart and
  systemd has been implemented for the Linux platform. Thanks to
  Pierre-Yves Ritschard and Marc Fournier. #798, #811, #814
  * collectd: The "CollectInternalStats" option has been added. Thanks to
  Yves Mettier. #691
  * collectd: The daemon source code and dependencies have moved to the
  "src/daemon/" directory. Thanks to Florian Forster.
  * collectd: The new "MaxReadInterval" option allows to cap the
  exponential retry interval of plugins read errors. Thanks to Alexey
  Remizov and Florian Forster. #713
  * collectd: The "-P" command-line option now has precedence over the
  "PIDFile" option. Thanks to Thomas D. #553
  * collection.cgi: Various data-source related adjustments have been
  made. Thanks to Fabiano Pires and Sebastian Harl.
  * libcollectdclient: Now propagates errors when signing / encrypting
  network packets. Thanks to Florian Forster.
  * Configuration: Support for unquoted IPv6 addresses has been added.
  Thanks to Sebastian Harl. #489
  * Documentation: Various improvements have been done. Thanks to Florian
  Forster and Marc Fournier.
  * Examples: the sample C plugin has been updated to the current plugin
  API. Thanks to Sebastian Harl.
  * Licensing: The following components have been relicensed to the MIT
  license: the Apple Sensors, Ascent, DBI, E-Mail, Entropy, GenericJMX,
  gmond, LogFile, nginx, Notify Desktop, NTPd, NUT, olsrd, Perl, Ping,
  PostgreSQL, Protocols, RouterOS, RRDCacheD, SNMP, StatsD, SysLog,
  Table, Tail, UnixSock, vmem, VServer, Wireless, Write Riemann and XMMS
  plugins, the core collectd daemon, the collectdmon, collectd-nagios
  and collectd-tg utilities, all the Targets and Matches, liboconfig,
  most of the "utils_*" files and the plugin API.
  * Tests: A test suite has been added. Thanks to Florian Forster.
  * Threshold: The hysteresis calculation has been made more reliable.
  Thanks to Jan Kundrát. #581
  * Threshold: Various fixes and improvements have been made. Thanks to
  Manuel Luis Sanmartín Rozada. #649, #644
  * AMQP plugin: The "ConnectionRetryDelay" option has been added,
  allowing to delay reconnection. Thanks to Yoga Ramalingam and Marc
  Fournier. #833
  * AMQP plugin: The "QueueDurable" and "QueueAutoDelete" options have
  been added, giving control over queue creation and deletion. Thanks to
  David Blundell and Marc Fournier. #623
  * Apache, Ascent, BIND, cURL, cURL-JSON, cURL-XML, nginx and Write HTTP
  plugins: Customizing the "User-Agent" field is now possible at
  compile-time. Thanks to Jeremy Katz. #440
  * Apache, Ascent, BIND, cURL, cURL-JSON, cURL-XML, nginx plugins: The
  connection will be reset if it hasn't completed within the configured
  "Interval". The new "Timeout" option gives control over this behavior.
  Thanks to Jan Kundrát and Marc Fournier. #982, #983, #993
  * Apache, Ascent, cURL, cURL-JSON, cURL-XML, nginx, Write HTTP plugins:
  Allow usernames and passwords to contain colons if built against
  libcurl ≧ 7.19.1. Thanks to Marc Fournier. #695, #947
  * Apache plugin: The "SSLCiphers" option gives control over the
  encryption algorithms to use with TLS connections. Thanks to Toni
  Moreno. #946
  * Barometer plugin: This new plugin reads sensor data from various
  Freescale and Bosch digital barometers. Thanks to Tomas Menzl. #69,
  [#693]
  * Battery plugin: Reporting values as percentages and reporting degraded
  batteries has been added. Thanks to Florian Forster.
  * Battery plugin: Support for reading values from sysfs on Linux has
  been added. Thanks to Andy Parkins, Nicholas Humfrey, Peter Wu and
  Florian Forster. #725, #810, #998
  * Battery plugin: The value for current is no longer supplied unless the
  battery provides this information. Thanks to Florian Forster.
  * BIND plugin: Bind's XML v3 API is now supported; Thanks to Victor
  Berger, Bruno Prémont and Michal Humpula. #742, #847
  * Ceph plugin: This new plugin collects statistics from the Ceph
  distributed storage system. Thanks to Dan Ryder, Dennis Zou, Colin
  McCabe, Sage Weil. #522, #598
  * ConnTrack plugin: Support for reporting values as percentages as well
  as legacy conntrack files in "/proc" has been added. Thanks to
  Pierre-Yves Ritschard. #497, #680
  * CPU plugin: The plugin is now able to report values as percentages and
  aggregate values per-state and per-CPU. Thanks to Pierre-Yves
  Ritschard, Florian Forster, Fabien Wernli, Nicholas Humfrey and
  Wilfried Goesgens. #499, #516, #639 #734, #812, #802
  * cURL-JSON plugin: Extracting values from complex JSON structures has
  been enhanced. Thanks to Jim Radford. #408, #411
  * cURL-JSON plugin: Intervals can now be configured on a per-URL basis.
  Thanks to Stan Sawa. #685
  * cURL-JSON, cURL-XML, Write HTTP plugins: These plugins now also follow
  HTTP redirects. Thanks to Marc Fournier.
  * cURL, cURL-JSON, cURL-XML plugins: HTTP Digest authentication has been
  implemented. Thanks to Frank Cornelis. #482
  * DBI, Oracle, PostgreSQL plugins: A "MetadataFrom" parameter has been
  added which allows to set metadata from database columns. Thanks to
  Mark Wong. #317, #321
  * DBI plugin: Querying several databases in parallel is now possible.
  Thanks to Vincent Bernat. #453
  * Disk plugin: On the Linux platform, disk names can now get looked up
  in udev with the "UdevNameAttr" option. Thanks to Patrick Mooney. #537
  * Disk plugin: This plugin now collects several additional I/O-related
  metrics on the Linux platform. Thanks to Florian Forster and Michael
  Schenck. #705, #759
  * DRBD plugin: This new plugin reads Linux's Distributed Replicated
  Block Device (DRBD) statistics. Thanks to Tim Laszlo. #566, #700
  * Exec, UnixSock plugins: The "PUTNOTIF" command now allows to set
  metadata on notifications. Thanks to John-John Tedro. #416
  * fhcount plugin: This new plugin reports the number of used file
  handles. Thanks to Jiri Tyr. #1009
  * GenericJMX plugin: A Class Loader for "JMXConnectorFactory" has been
  added, allowing the plugin to work with JBOSS > 7. Thanks to Alexandre
  Moutot. #452
  * IPC plugin: This new plugin collects information related to shared
  memory. Thanks to Andrés J. Díaz. #925
  * Java plugin: Now uses the hostname defined in the configuration file.
  Thanks to Pierre-Yves Ritschard. #530, #681
  * Load plugin: The plugin is now able to report values as percentages.
  Thanks to Vedran Bartonicek and Pierre-Yves Ritschard. #344, #498
  * Log Logstash plugin: This new plugin writes collectd logs and events
  as Logstash JSON formatted events. Thanks to Pierre-Yves Ritschard.
  [#360]
  * LVM plugin: The plugin collects thin pool data volumes size, and no
  longer reports virtual volumes. Thanks to Benjamin Gilbert. #603
  * memcached plugin: "listen_disabled_num" are now also reported. Thanks
  to Matt Cottingham. #622
  * Memory plugin: Slab memory reporting on the Linux platform has been
  added. Thanks to Manuel CISSÉ and Marc Fournier. #560, #697
  * Memory plugin: The plugin is now able to report values as percentages.
  Thanks to Jeremy Katz, Florian Forster and Manuel CISSÉ. #501, #511,
  [#559]
  * Modbus plugin: Selecting between holding and input registers is now
  possible. Thanks to Jan Vitek. #338
  * Modbus plugin: Support for accessing devices through an RS-485 serial
  port has been added. Thanks to Eric Sandeen.
  * Multimeter plugin: This plugin isn't built by default on the AIX
  platform anymore. Thanks to Manuel Luis Sanmartin Rozada. #549, #684
  * MySQL and PostgreSQL plugins: Passing "127.0.0.1" as a host will now
  result in the global Hostname being used in metric names. Thanks to
  Jeremy Katz. #441
  * MySQL plugin: InnoDB, Select and Sort statistics collection has been
  added. Thanks to Wilson Felipe, Marek Becka and Pierre-Yves Ritschard.
  [#248], #621, #699, #824
  * MySQL plugin: The "Alias" and "ConnectTimeout" options have been
  added. Thanks to William Tisäter.
  * Netlink plugin: Support for 64bit netlink counters has been added.
  Thanks to Marek Becka. #435
  * Network plugin: The "ReconnectInterval" configuration option has been
  added. Thanks to John Ferlito. #732
  * NFS plugin: Support for NFSv4.0 has been implemented. Thanks to Marek
  Becka. #550
  * OneWire plugin: Support for more temperature-providing sensor families
  has been added. Thanks to Tomasz Torcz. #672
  * OneWire plugin: Support for full OWFS path and more device families
  has been implemented. Thanks to Tomas Menzl. #68
  * OpenLDAP plugin: This new plugin reads monitoring information from
  OpenLDAP's "cn=Monitor" subtree. Thanks to Kimo Rosenbaum, Marc
  Fournier and Nicholas Humfrey. #719
  * OpenVPN plugin: Support for OpenVPN 2.3.0 has been implemented. Thanks
  to Ed Okerson. #252
  * OpenVZ plugin: Various improvements have been made, making the plugin
  report values like the other collectd plugins do. Thanks to Chris
  Lundquist. #264
  * Perl plugin: A new "listval_filter" method has been added, various
  internal cleanups and improvements have been made and a test suite has
  been added. Thanks to Matthias Bethke. #728
  * PostgreSQL plugin: The new "ExpireDelay" option allows skipping older
  values pending write when the database slows down. Thanks to Stephen
  O'Dor. #593
  * PowerDNS plugin: The plugin was updated for stats from pdns 3.4.3.
  Thanks to Ruben Kerkhof. #965
  * Processes plugin: A memory-usage related optimization for low-profile
  systems has been added. Thanks to Florian Forster. #652
  * Python plugin: Support for Python3 has been improved, "ModulePath" is
  now prepended to "sys.path", and the "get_dataset()" function has been
  added to the Python API. Thanks to Sven Trenkel and Patrick Browne.
  [#890], #751, #771
  * Redis and Write_Redis plugins: The support library has been switched
  from credis to hiredis. Thanks to Andrés J. Díaz, Victor Seva, Marc
  Fournier, Johan Bergström, Michael Spiegle and brianpkelly. #296,
  [#464], #475, #799, #1030
  * Redis plugin: Custom commands can now be used to fetch values stored
  in Redis. Thanks to Pierre-Yves Ritschard. #816
  * Redis plugin: Support for passwords up to 512 characters long has been
  added. Thanks to Jeremy Katz. #532
  * Sensors plugin: Support for lm_sensors' power sensors has been added.
  Thanks to Jan Kundrát. #571
  * SMART plugin: This new plugin collects SMART statistics from disk
  drives. Thanks to Vincent Bernat. #797
  * SNMP plugin: A blacklist/whitelist feature can now be used to filter
  which OIDs to collect. Thanks to Christophe Courtaut. #414
  * SNMP plugin: SNMPv3 authentication and encryption support has been
  implemented. Thanks to Michael Pilat. #362
  * SNMP plugin: Two error messages have been disambiguated. Thanks to
  Sergey. #939, #952
  * Swap plugin: The plugin is now able to report values as percentages.
  Thanks to Jeremy Katz and Florian Forster. #500, #510
  * Swap plugin: The plugin no longer fails on Linux systems where
  "SwapCached" isn't exposed by the kernel. Thanks to Florian Forster.
  [#733]
  * Tail plugin: "GaugeInc" and "GaugeAdd" options have been implemented.
  Thanks to Andre Ferraz. #673
  * Tail plugin: Intervals can now be configured on a per-File basis.
  Thanks to Tom Leaman. #446
  * TCPConns plugin: The "AllPortsSummary" option, allowing to summarize
  all connections, has been added. Thanks to Marek Becka. #488
  * TCPConns plugin: Three metrics were renamed on the AIX platform, for
  the sake of consistency. Thanks to Manuel Luis Sanmartín Rozada. #546
  * Turbostat plugin: This new plugin reads CPU frequency and C-state
  residency on modern Intel turbo-capable processors. Thanks to Vincent
  Brillault, Jean Delvare and Nicolas Iooss. #651
  * UnixSock plugin: The "GETTHRESHOLD" command has been re-added. Thanks
  to Manuel Luis Sanmartín Rozada. #674
  * Varnish plugin: Varnish 4 support has been added, as well as as
  monitoring metrics only available in Varnish 4. Thanks to Marc
  Fournier. #618, #783
  * virt plugin: Guests memory usage is now also collected. Thanks to
  Tiago Carvalho, jazzmes and Zollner Robert.
  * virt plugin: It is now possible to chose between using guests' name or
  UUID as plugin_instance. Thanks to Remi Ferrand. #385
  * virt plugin: The libvirt plugin has been renamed to virt. Thanks to
  Florian Forster.
  * Write Graphite plugin: When the connection to graphite fails,
  reconnection attempts are now limited to once per second. Thanks to
  Florian Forster. #625
  * Write HTTP plugin: Multi-instance support of this plugin has been
  improved. The "<URL "url">" block has been deprecated in favor of
  "<Node "identifier">". Thanks to Marc Fournier. #902
  * Write HTTP plugin: Several TLS-related configuration options have been
  added. Thanks to Ingmar Runge. #666
  * Write HTTP plugin: The "LowSpeedLimit" and "Timeout" options allow to
  reset slow/stalled network connections. Thanks to loginator17 and Marc
  Fournier. #752, #985
  * Write HTTP plugin: The size of the payload posted to the HTTP server
  can now be controlled with the "BufferSize" option. Thanks to Florian
  Forster. #722
  * Write Kafka plugin: This new plugin sends data to Apache Kafka, a
  distributed messaging queue. Thanks to Pierre-Yves Ritschard,
  ciomaire, Vincent Bernat, Marc Fournier. #670, #694, #794, #853, #014
  * Write Log plugin: This new plugin dispatches collected values to the
  configured log destination(s). Thanks to Pierre-Yves Ritschard. #886
  * Write Riemann plugin: Extra meta strings are now added as attributes
  in notifications. Thanks to John-John Tedro. #417
  * Write Riemann plugin: Notification message are now sent to the Riemann
  server via the description field. Thanks to Adrian Miron. #575
  * Write Riemann plugin: Support for custom attributes has been added.
  Thanks to Pierre-Yves Ritschard. #459
  * Write Riemann plugin: Support had been implemented for sending events
  to Riemann in batches (when using TCP), and is enabled by default.
  Thanks to Pierre-Yves Ritschard. #800
  * Write Riemann plugin: The "EventServicePrefix" option has been added,
  which adds a prefix to event service names. Thanks to Moshe Zada. #706
  * Write Riemann plugin: Threshold checks can now be passed down to the
  Riemann server. Thanks to Pierre-Yves Ritschard. #518
  * Write Sensu plugin: This new plugin submits values to Sensu, a stream
  processing and monitoring system. Thanks to Fabrice A. Marie and Marc
  Fournier. #912, #1001, #1016
  * Write TSDB plugin: This new plugin sends data to OpenTSDB, a scalable
  time series database. Thanks to Kevin Bowling, Florian Forster, Dallin
  Young, Michael Schenck and Pierre-Yves Ritschard. #703, #772, #945
  * ZFS ARC plugin: Support for ZFS-on-Linux has been added. Thanks to
  Marc Fournier and Wilfried Goesgens. #552
  * Zookeeper plugin: This new plugin reads data from the Apache Zookeeper
  "MNTR" command. Thanks to Jeremy Katz. #826
* Thu Jan 14 2016 aj@ajaissle.de
- Added %%bcond for modbus
* Thu Dec 17 2015 ro@suse.de
- add patch collectd-new_libstatgrab.patch:
  fix build with recent libstatgrab (basically backport from git)
- do not (build)require sensors on s390/s390x
* Sat Sep 12 2015 matwey.kornilov@gmail.com
- Add modbus plugin
* Fri Jun  5 2015 mpluskal@suse.com
- Change _service to mode='localonly' active services are not
  allowed in factory
* Mon Mar  2 2015 bruno@ioda-net.ch
- packaging :
  deleted source collectd.service, use now upstream version in contrib
  spec_cleaner .spec
- upstream update bugfix release 2015-02-26, Version 5.4.2
  * Build system: Numerous fixes. Thanks to Bjørn Nordbø, Jim Radford,
  KOMEDA Shinji, Lauri Tirkkonen, Manuel Luis Sanmartin Rozada, Marc
  Fournier, Rainer Müller, Yoga Ramalingam and Yves Mettier. #326,
  [#373], #653, #828
  * collectd: A use-after-free has been fixed in the "parse_value()"
  function. Thanks to Matthias Urlichs.
  * collectd: Fix carriage return sign in types_list Thanks to Marc
  Fournier and @NsLib.
  * collectd: Fix programming error in src/configfile.c. Thanks to
  Wilfried Goesgens.
  * collectd: An off-by-one error has been fixed in the
  "strstripnewline()" function. Patch by Florian Forster.
  * collectd: Use the complain mechanism to report filter chain write
  failures. Thanks to Sebastian Harl.
  * collectd: Spelling and grammar of error messages have been fixed.
  Thanks to Katelyn Perry and Tim Laszlo.
  * collectdctl: Fixed buffering issues which caused trouble on AIX and
  Solaris. Thanks to Yoga Ramalingam.
  * Documentation: Details and example about multi-instance filterchain
  targets have been added. Thanks to Marc Fournier.
  * Documentation: The "CollectStatistics" option of the rrdcached has
  been documented. Thanks to Micha Krause. #907
  * Documentation: The write_redis has been documented. Thanks to Marc
  Fournier.
  * Documentation: The "GraphiteSeparateInstances" and
  "GraphiteAlwaysAppendDS" options of the amqp have been documented.
  Thanks to Marc Fournier.
  * Documentation: Documentation of the "AutoLoadPlugin" option has been
  improved. Thanks to Florian Forster. #715
  * aggregation: "utils_vl_lookup": A race when creating user objects
  has been fixed. Thanks to Sebastian Harl. #535
  * cpu: Temperature code for MacOSX has been removed.
  Thanks to Florian Forster and Marc Fournier. #22
  * cURL, cURL-JSON, cURL-XML and Write HTTP plugins: Call
  "curl_global_init()" in the plugins' "init()" callback. Thanks to
  Jeremy Katz.
  * cURL and memcachec plugins: Fix calculation of gauge, average,
  minimum and maximum. Previously, they were calculated from the start
  of the daemon, which is not the documented behavior. Thanks to
  Florian Forster. #663
  * curl-json: A bug, which triggered when two URLs with a long common
  prefix were configured, was fixed. Thanks to Marc Fournier. #582
  * dbi: Compatibility with new versions of libdbi has been restored.
  Thanks to Florian Forster. #950
  * Exec, UnixSock plugins: Fix parsing of the "time" option of the
  "PUTNOTIF" command. Thanks to Adrian Miron. #477
  * ipmi: A conflict with the java over the "SIGUSR2" signal has been
  fixed. Thanks to Vincent Bernat. #114
  * java: Conversion from Java's time representation to collectd's
  representation has been fixed. Thanks to Manuel Luis Sanmartín
  Rozada.
  * java: Make sure "cjni_thread_detach()" is called on all paths.
  Thanks to Florian Forster.
  * LogFile and SysLog plugins: Avoid total silence in case of a
  misconfiguration. Thanks to Marc Fournier and Wilfried Goesgens.
  * network: Support for recent versions of gcrypt has been added.
  Thanks to Vincent Bernat. #632
  * network: Robustness of the client connecting behavior has been
  improved. Thanks to Florian Forster. #627
  * python: Don't create empty "meta_data_t" objects. Thanks to Florian
  Forster. #716
  * python: Fix Py list length check in "cpy_build_meta()". Thanks to
  Yoga Ramalingam.
  * python: The "interval" member was fixed to export seconds as a
  double. Thanks to Justin Burnham.
  * RRDtool and RRDCacheD plugins: A memory leak when creating RRD files
  has been fixed. Thanks to Yves Mettier. #661
  * snmp: Fix a memory leak. Thanks to Marc Fournier and Pierre-Yves
  Ritschard. #610, #804
  * statsd: Support for samplerates in timer metrics was added. Thanks
  to John Leach. #461
  * swap: Fix behavior under OpenVZ by making "cached" optional. Thanks
  to Florian Forster. #733
  * threshold: Population of the "time" field in notifications has been
  added. Thanks to Manuel Luis Sanmartín Rozada.
  * libvirt: Only gather stats for running domains. Thanks to Ruben
  Kerkhof.
  * lvm: An issue with Volume Groups (VGs) without Logical Volumes (LVs)
  has been fixed. Thanks to Jan Kundrát.
  * write_graphite: Escape characters not supported by Graphite. Thanks
  to Pierre-Yves Ritschard and Marc Fournier.
  * write_http: Make callback names context-dependent. Thanks to Marc
  Fournier. #821
  * write_redis: A formatting bug, which resulted in totally unusable
  numbers being transmitted to Redis, was fixed. Thanks to Marc
  Fournier.
  * write_riemann: Receive acknowledge message when using TCP. Thanks to
  John-John Tedro.
* Sun Nov  9 2014 seife+obs@b1-systems.com
- do not create a journal entry for every PUTVAL e.g. from the
  exec plugin, collectd-5.4.1-exec-no-output.diff
- remove crazy kernel-source build dependency
- fix smp_mflags spelling to really build with multiple jobs
- make build output verbose to let rpmlint find problems
* Sun Jul 20 2014 p.drouand@gmail.com
- Do not provide support for systemd and sysvinit on the same system
  it's redundant
- Add a rc symlink with systemd service file for backward compatibility
* Sat Mar 15 2014 bruno@ioda-net.ch
- update to version 5.4.1, a new bugfix release Changes include:
  * AMQP plugin: Add support for RabbitMQ 0.4.x to avoid compiler warnings.
  Thanks to Sebastian Harl for implementing this.
  * Apache / Network plugins: Improved initialization order hopefully resolved
  gcrypt initialization problems.
  * Aquaero plugin: The type used to submit fan utilization was fixed. Thanks
  to Alex Deymo for the patch.
  * cgroups plugin: A small memory leak was fixed. Checking the existence of a
  mount option without a value was fixed. More permissive parsing of the
  cpuacct.stats file fixes support for some versions of Linux. Thanks to Marc
  Fournier for bug reports and patches.
  * cURL plugin: Fix <Match> blocks without an instance. Thanks to Alexander
  Golovko for reporting and Sebastian Harl for fixing this.
  * cURL-JSON plugin: Potentially invalid memory access has been sanitized.
  Thanks to Jim Radford for his patch.
  * Interface plugin: Fix behavior under FreeBSD 10: Reporting of per-address
  statistics caused duplicate updates to the same metric. Thanks to demon
  / @trtrmitya for the patch.
  * Write Graphite plugin: Use TCP to connect to Graphite by default. The
  default changed from TCP to UDP between 5.3.1 and 5.4.0, which is a
  regression. Thanks to Marc Fournier for fixing this. Reconnect behavior
  was improved. Thanks to Michael Hart for his patch.
  * ZFS ARC plugin: Collect "allocated" and "stolen" on FreeBSD only. -
- Packaging :
  * rework of patch collectd-version.patch against 5.4.1 source
  * rework collectd-pkgconfig_libnotify_add_gtk.patch against 5.4.1
  As it should not be used since 2012. (gtk-2.0) if now only applied for
    11.4 Evergreen
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Fri Aug 23 2013 pascal.bleser@opensuse.org
- update to 5.4.0:
  * collectd: The "LoadPlugin" config option no longer attempts to load
    plugins twice. If more than one "LoadPlugin" statement or block is
    encountered, only the first will have any effect.
  * collectd: The "AutoLoadPlugin" option allows to automatically load
    plugins for which a configuration is found.
  * collectd: The "WriteQueueLimitHigh" and "WriteQueueLimitLow" options
    allow collectd to drop values when under stress, to avoid running out
    of memory.
  * amqp plugin: The "GraphiteSeparateInstances" and
    "GraphiteAlwaysAppendDS" options have been added.
  * aquaero plugin: This new plugin reads various metrics, e.g. fan
    speeds and temperatures, from Aquaero 5, a fan and water cooling
    control panel.
  * curl plugin: The "MeasureResponseCode" option has been added.
  * curl_json plugin: Support for UNIX domain sockets and array wildcards
    has been added.
  * curl_xml plugin: Support for long URLs has been improved.
  * cgroups plugin: This new plugin collects CPU accounting information
    for processes in a cgroup.
  * df plugin: The "ValuesAbsolute" and "ValuesPercentage" options have
    been added.
  * exec plugin: Do UID / GID lookups before forking. This should prevent
    a race condition in the NSS library.
  * lvm plugin: This new plugin collects size information from Linux'
    Logical Volume Manager (LVM).
  * memcached plugin: Support for increment and decrement counts has been
    added.
  * mic plugin: This new plugin collects CPU and memory usage, power
    consumption and temperatures of Intel's Many-Integrated-Core (MIC)
    architecture, such as Xeon Phi cards.
  * netlink plugin: This plugin has been converted to use the supported
    "libmnl" library.
  * nginx plugin: Collection of accepted and handled connections has been
    added.
  * sigrok plugin: This new plugin collects metrics from sigrok, a signal
    processing framework reading various hardware devices, from light
    meters to spectrum analyzers.
  * statsd plugin: This new plugin listens to a UDP socket and reads
    metrics in the StatsD format.
  * varnish plugin: Many additional metrics have been added.
  * write_graphite plugin: Support for "UDP" has been added.
  * write_riemann plugin: The "TTLFactor" option has been added.
- changes from 5.3.1:
  * Configuration: Fix error handling: Errors in included files were
    ignored, causing configuration mistakes to go unnoticed.
  * dns plugin: Don't abort when PCAP returns an error.
  * modbus plugin: The reconnection strategy was improved, fixing a
    segfault in the libmodbud library.
  * mysql plugin: The notification about a newly running MySQL slave
    thread has been fixed.
  * snmp plugin: A build issue has been fixed (C99 mixed declaration).
  * threshold plugin: Handling of the "Interesting" configuration option
    has been fixed.
  * write_riemann plugin: A memory leak has been fixed.
- dropped collectd-fix-warnings.patch, as it only fixed warnings in the
  netlink plugin, which has been rewritten
- disable dns plugin on SLE_11_SP2, libpcap too old there
* Fri Aug 23 2013 pascal.bleser@opensuse.org
- update to 5.3.0:
  * collectd: The "Include" statements can now be limited to include
    only matching files in a directory
  * collectd: Dispatches / writes are now handled by a thread pool. This
    improves reliability and throughput for instances configured to act
    as a "server"
  * aggregation plugin: Selection of value lists is now possible using
    regular expressions. Parts of the identifier of the resulting metric
    can now be set via the configuration file.
  * apcups plugin: The "ReportSeconds" option has been implemented.
  * curl* plugins: Support for POST requests and custom request headers
    has been added
  * curl_xml plugin: Support for XML namespaces has been added.
  * dbi plugin: Support for numeric options has been added. The
    "Host" option has been added.
  * disk plugin: Support for systems with >256 has been fixed
  * libvirt plugin: Support for memory allocation has been added.
  * netapp plugin: Support for "SnapVault", "VFiler" and deduplication /
    compression and quota metrics.
  * postgresql plugin: The reconnection logic has been improved.
  * rrdtool, rrdcached plugins: The "CreateFilesAsync" option has been
    implemented. When enabled, new RRD files will be created
    asynchronously, which improved throughput of "server" instances.
  * tail_csv plugin: This new plugins allows to read metrics from CSV
    files, such as Snort's statistics file.
  * write_mongodb plugin: Authentication options have been added.
  * write_riemann plugin: This new plugin allows sending metrics to
    Riemann, a stream processing and alerting tool.
- dropped own copy of iproute2, builds properly with the one provided
  by the system
* Thu Aug  1 2013 tchvatal@suse.com
- Tarball was actually broken, rather stick with no download url,
  because upstream provides only 3.0 and newer for download now.
* Thu Aug  1 2013 tchvatal@suse.com
- Update the tarball so download_files serivce is silent.
* Fri Jun 28 2013 coolo@suse.com
- fix more of spamassasin's doc
* Mon Aug 27 2012 crrodriguez@opensuse.org
- Add systemd rules.
* Mon Jul 30 2012 chris@computersalat.de
- fix deps for iptables
  * iptables-devel works for > 1020
  * > 12.1 'split iptables-devel into libiptc-devel and libxtables-devel'
* Mon Jun 11 2012 coolo@suse.com
- require the right perl version
* Mon Apr 23 2012 aj@suse.de
- Drop collectd-fix_new_yajl_lib.patch and collect-libnotify_070.patch
  both are handled in the new version.
* Tue Apr 17 2012 pascal.bleser@opensuse.org
- changed copyright from GPL-2.0+ to GPL-2.0, see bnc#757527:
  https://bugzilla.novell.com/show_bug.cgi?id=757527
- added myself to the copyright header in the spec file, have been maintaining
  this spec file since 2005 ;)
* Mon Apr 16 2012 aj@suse.de
- Remove modbus support since modbus is not in openSUSE:Factory.
- Fix buildrequires: it's libxtables-devel for 12.2.
* Tue Apr  3 2012 pascal.bleser@opensuse.org
- update to 5.0.4
* Sun Feb 19 2012 pascal.bleser@opensuse.org
- add modbus support
* Sun Feb 19 2012 pascal.bleser@opensuse.org
- fix apache configuration for collectd-js, thanks to Bruno Friedmann
  <tigerfoot@opensuse.org> for reporting
* Sun Feb 19 2012 pascal.bleser@opensuse.org
- update to 5.0.3: too many changes to list, please read ChangeLog in the main
  package
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Mon Oct 17 2011 schubi@suse.com
- fixed build ( new yajl lib API )
* Fri Sep 16 2011 coolo@suse.com
- adding patch from jengelh to fix build
* Tue Aug  2 2011 stefan.bruens@rwth-aachen.de
- notify-desktop: fix compatibility with libnotify >= 0.7.0
- iptables plugin: use iptables library
- ipvs plugin: disable for >= 12.1, as build fails currently
* Mon Aug  1 2011 stefan.bruens@rwth-aachen.de
- df plugin: skip duplicate entries, fixes "uc_update: Value too old"
  error
* Sat Apr 16 2011 pascal.bleser@opensuse.org
- downgrading in-tree iproute2 from 2.6.38 to 2.6.37, as 2.6.38 causes an
  internal error in gcc
* Fri Apr 15 2011 pascal.bleser@opensuse.org
- add pinba plugin (through protobuf-c support)
- add rpmlintrc file to suppress false positives
- add collectd-pkgconfig_libnotify_add_gtk.patch to fix building libnotify
  support on >= 11.4
* Wed Apr 13 2011 pascal.bleser@opensuse.org
- bump in-tree iproute2 to 2.6.38
- update to 4.10.3:
  * collectd: Threshold subsection: Handling of NAN values in the percentage
    calculation has been fixed
  * collectd, java plugin, ntpd plugin: Several diagnostic messages have been
    improved
  * curl_json plugin: Handling of arrays has been fixed.
  * libvirt plugin: A bug in reading the virtual CPU statistics has been fixed
  * processes plugin: Potentially erroneous behavior has been fixed in an error
    handling case
  * python plugin: Fix dispatching of values from Python scripts to collectd
- changes from 4.10.2:
  * collectd: If including one configuration file fails, continue with the rest
    of the configuration if possible
  * collectd: Fix a bug in the read function scheduling. In rare cases read
    functions may not have been called as often as requested
  * collectd: A left-over hard-coded 2 has been replaced by the configurable
    timeout value
  * curl, memcachec, tail plugins: Fix handling of "DERIVE" data sources.
    Matching the end of a string has been improved
  * curl_json plugin: Fix a problem when parsing 64bit integers. Reading JSON
    data from non-HTTP sources has been fixed
  * network plugin: Be less verbose about unchecked signatures, in order to
    prevent spamming the logs
  * notify_email plugin: Concurrency problems have been fixed
  * python plugin: Set "sys.argv", since many scripts don't expect that it may
    not be set
  * rrdtool, rrdcached plugin: Fix a too strict assertion when creating RRD
    files
  * swap plugin: A bug which lead to incorrect I/O values has been fixed
  * value match: A minor memory leak has been fixed
* Mon Jul 12 2010 pascal.bleser@opensuse.org
- add curl_json plugin (libyajl)
- fix Java plugin on 11.1
* Sun Jul 11 2010 pascal.bleser@opensuse.org
- update to 4.10.1:
  * the shutdown speed when terminating the read threads has been improved
  * libcollectdclient: a format error in the PUTVAL command has been removed
  * DF plugin: an error message shown when cu_mount_getlist fails has been added
  * Processes plugin: missing initialization code for IO members of a struct has been added
  * Python plugin: memory leaks in the write and notification callbacks have
    been fixed; a possible crash when the plugin was loaded but not configured
    has been fixed
  * SNMP plugin: verbosity with regard to unknown ASN types has been increased
  * PowerDNS plugin: compatibility changes for PowerDNS 2.9.22 and above have been applied
- changes from 4.10.0:
  * JSON output now includes the dstypes and dsnames fields
  * the new Timeout option can be used to specify a timeout for missing values
  * Apache plugin: support for IdleWorkers (Apache 1.*: IdleServers) has been added
  * cURL plugin: the new ExcludeRegex allows to easily exclude certain lines
    from the match
  * cURL-XML plugin: new plugin allows to read XML files using cURL and extract
    metrics included in the files
  * FileCount plugin: the new IncludeHidden option allows to include hidden
    files and directories in the statistics
  * LogFile plugin: the new PrintSeverity option allows to include the severity
    of a message in the output
  * memcachec plugin: the new ExcludeRegex allows to easily exclude certain
    lines from the match
  * Network plugin: new Interface option allows to set the interface to be used
    for multicast and, if supported, unicast traffic
  * OpenVPN plugin: the CollectUserCount and CollectIndividualUsers options
    allow more detailed control over how to report sessions of multiple users
  * Ping plugin: new MaxMissed allows to re-resolve a hosts address when it
    doesn't reply to a number of ping requests
  * PostgreSQL plugin: the Interval config option has been added; the plugin
    has been relicensed under the 2-clause BSD license
  * Processes plugin: support for code and data virtual memory sizes has been
    added
  * Python plugin: support for Python 3 has been implemented
  * Swap plugin: support for Linux < 2.6 has been added
  * Tail plugin: the new ExcludeRegex allows to easily exclude certain lines
    from the match
  * Write HTTP plugin: the StoreRates option has been added
  * RegEx match: the Invert option has been added
- bumped in-tree libnetlink_version version from 2.6.33 to 2.6.34
* Fri Apr 23 2010 pascal.bleser@opensuse.org
- bumped in-tree libnetlink_version version from 2.6.29-1 to 2.6.33
- update to 4.9.2:
  * append a newline to messages written to STDERR.
  * serialization of NANs in JSON format has been fixed
  * checks whether a "sleep" returned early have been added
  * continue reading files in a directory when parsing one file fails
  * Apache plugin: collection of the number of active connections has been
    fixed for Apache 2.*
  * Exec plugin: error messages have been improved; the "running" flag is now
    cleared correctly when forking a child fails
  * IPTables plugin: fix a violation of aliasing rules
  * Java plugin: the Java API files are now packaged into a .jar file
  * Network plugin: fix a segmentation fault when receiving packets with an
    unknown data source type
  * Network plugin: a memory leak when receiving encrypted network packets has
    been fixed
  * Oracle plugin: fix checking for lost connections and reconnect in this case
  * UnixSock plugin: a memory leak in the "LISTVAL" command has been fixed
  * Write HTTP plugin: use the "any" authentication schema, used to be "digest"
* Fri Jan 15 2010 pascal.bleser@opensuse.org
- update to 4.9.1:
  * RRDtool plugin: fix a bug with random write timeouts: due to an
    incorrect initialization some files may be suspended basically
    indefinitely; after flushing the files they were written
    regularly again
  * documentation: some manpage fixes
  * default config: added sample configuration for missing plugins
  * apache plugin: fix a segmentation fault in the config handling
    of VerifyPeer / VerifyHost
  * processes plugin: fix handling of derive data sources
  * RouterOS plugin: use the node name for the "host" field
  * monitorus plugin: put the plugin into the "Collectd::Plugins"
    namespace
  * Perl bindings: fix a warning that was printed when building
    debugging output
* Mon Dec 21 2009 pascal.bleser@opensuse.org
- update to 4.9.0:
  * new plugins: NetApp, Python, RouterOS, ContextSwitch, Monitorus,
    OpenVZ
  * timing information is now collected in the cURL plugin
  * the possibility to set the source address and device used has
    been added to the Ping plug-in
  * the detail provided by the DF plug-in has been enhanced
  * collection of IO-metrics has been added to the Processes plugin
* Sat Dec 19 2009 pascal.bleser@opensuse.org
- update to 4.8.2:
  * fixes a memory leak in the "listval" command
  * adds detection of dead connections and reconnection in the GenericJMX and
    Oracle plugins
  * fixes handling of negative values and hex strings has been corrected in the
    SNMP plugin
  * improved treatment of error messages when no log plugin was loaded
- build memcachec and dbi plugins
* Tue Oct  6 2009 pascal.bleser@opensuse.org
- split out -virt plugin package to avoid depending on libvirt.so and libxenstore.so
  in the main package
- more preconfigured integration and documentation mangling for files under contrib/
- split out spamassassin contrib files into their own package, properly preconfigured
- fix Apache2 configuration file in -web subpackage
* Sat Oct  3 2009 pascal.bleser@opensuse.org
- update to 4.8.1:
  * UnixSock plugin: fix a (well hidden) race condition related to file descriptor handling
- changes from 4.8.0:
  * collectd: two new data source types, DERIVE and ABSOLUTE, have been added:
    DERIVE can be used for counters that are reset occasionally
  * thresholds: the advanced threshold options “Percentage”, “Hits”, and
    “Hysteresis” have been added
  * cURL-JSON plugin: the new cURL-JSON plugin reads JSON files using the cURL
    library and parses the contents according to user specification; among
    other things, this allows to read statistics from a CouchDB instance
  * DF plugin: using the new “ReportByDevice” option the device rather than the
    mount point can be used to identify partitions
  * DNS plugin: the possibility to ignore numeric QTypes has been added
  * GenericJMX plugin: the new, Java-based GenericJMX plugin allows to query
    arbitrary data from a Java process using the Java Management Extensions
    (JMX)
  * MadWifi plugin: the new MadWifi plugin collects information about Atheros
    wireless LAN chipsets from the MadWifi driver
  * network plugin: the receive- and send-buffer-sizes have been made
    configurable, allowing for bigger and smaller packets
  * olsrd plugin: the new OLSR plugin queries routing information from the
    Optimized Link State Routing daemon
  * RRDtool plugin: a new configuration option allows to define a random write
    delay when writing RRD files; this spreads the load created by writing RRD
    files more evenly
  * Swap plugin: the possibility to collect swapped in/out pages has been added
    to the Swap plugin
  * TokyoTyrant plugin: the new TokyoTyrant plugin reads the number of records
    and file size from a running Tokyo Tyrant server
  * UnixSock plugin: add the GETTHRESHOLD command: this command can be used to
    query the thresholds configured for a particular identifier
  * Write HTTP plugin: the new Write HTTP plugin sends the values collected by
    collectd to a web-server using HTTP POST requests
  * Empty Counter match: the new Empty Counter match matches value lists, where
    at least one data source is of type COUNTER and the counter value of all
    counter data sources is zero
* Fri Sep 25 2009 kkaempf@suse.de
- temporarily disable perl plugin for opensuse 11.2, must fix configure check
  first
* Sun Jul 26 2009 pascal.bleser@opensuse.org
- update to 4.7.2:
  * several bugs in the threshold and notification subsystems have been fixed
  * portability of the “memcached” plug-in has been improved
* Tue May 12 2009 pascal.bleser@opensuse.org
- update the in-tree libnetlink to 2.6.29-1
- added missing ldconfig for libcollectclient0
- update to 4.7.0:
  * apache plugin: support to query multiple servers has been added
  * apache plugin: handling of lighttpd's scoreboard statistics has been
    improved
  * conntrack plugin: the new conntrack plugin collects the connection tracking
    table size
  * fscache plugin: the new fscache plugin collects statistics about Linux'
    file-system based caching framework
  * gmond plugin: the new gmond plugin can receive and interpret multicast
    traffic from Ganglia's gmond daemon
  * java plugin: the new java plugin exports the collectd API to Java, making
    it possible to write extensions to collectd in Java
  * memcachec plugin: the new memcachec plugin queries data from a memcached
    daemon and parses it similar to the cURL plugin
  * memcached plugin: support for connections over UNIX domain sockets has been
    added
  * mysql plugin: support to query multiple databases has been added
  * mysql plugin: master/slave statistics have been added
  * mysql plugin: lock statistics have been added
  * network plugin: the possibility to sign or encrypt network traffic has been
    added
  * protocols plugin: the new protocols plugin provides information about
    network protocols, such as IP, TCP and UDP
  * snmp plugin: the intervals given in the configuration of the SNMP plugin
    must no longer be a multiple of the global interval
  * table plugin: the new Table plugin provides parsing for table-like
    structured files, such as many files beneath /proc
  * ted plugin: the new TED plugin reads power consumption measurements from
    “The Energy Detective” (TED)
  * onewire plugin: the new Interval option allows collecting information from
    OneWire sensors at arbitrary intervals
  * ping plugin: support for collecting the drop rate and standard deviation of
    round-trip times has been added
  * uptime plugin: the new uptime plugin can collect the server's uptime
* Wed Mar 18 2009 pascal.bleser@opensuse.org
- update to 4.6.2:
  * collection of the number of cached RR-sets has been fixed in the "BIND"
    plugin
  * filter chains can now be configured without a default target
  * portability fixes have been added to the "DNS" and "Oracle" plugins
  * a typo that prevented the module from being used correctly has been
    corrected in the "TimeDiff" match
  * a possible race condition during startup has been fixed in the "RRDtool"
    plugin
* Sun Feb 22 2009 pascal.bleser@opensuse.org
- update to 4.6.1:
  * fixes an off-by-one error in the IPMI plugin
  * fixes smaller problems in the BIND plugin
  * documentation fixes
- upgrade in-tree libnetlink (iproute2) library to latest (2.6.28)
* Mon Feb 16 2009 guru@unixtech.be
- fix build on 11.1, make rpmlint happy
* Sun Oct 19 2008 guru@unixtech.be
- only expect the virt plugin on >=11.0 as collectd now requires a more
  recent libvirt (>=0.4.0, for virDomainBlockStats)
* Fri Oct 17 2008 guru@unixtech.be
- moved collectd-snmp manpage to -snmp subpackage
- update to 4.5.1:
  * fix a memory leak in the global value cache and configuration handling
    code
  * fix an off-by-one error in the ignorelist functionality
  * collectdmon: don't block SIGCHLD, fixes a potential portability problem
  * collectd-nagios: fix handling of the -d option
  * iptables plugin (4.5.1 only): fix an off-by-one error
  * perl plugin: log an error message if bootstrapping Collectd fails
  * postgresql plugin (4.5.1 only): don't reopen connection during
    reinitialization
  * snmp plugin (4.5.1 only): don't expect null-terminated strings from the
    Net-SNMP library
  * tail plugin: call clearerr(3) after reading an EOF
* Thu Sep 11 2008 guru@unixtech.be
- added a patch to remove poisoning of strcpy on openSUSE < 11.0,
  as it is replaced by a safe bounds-checking variant using a #define
* Wed Sep 10 2008 guru@unixtech.be
- added postgresql subpackage
- moved mysql into own subpackage
- added libvirt, filecount, notify_desktop and thermal plugins
- bump the in-tree iproute2 to 2.6.26
- update to 4.5.0:
  * fix a memory leak in the threshold checking code
  * memcached plugin: fix a too short timeout and a related file descriptor
    leak
  * memory plugin: a typo in the libstatgrab code has been fixed
  * snmp plugin: fix a possible memory leak
* Wed May  7 2008 guru@unixtech.be
- well-defined list of plugins to avoid unpredictable build results caused
  by missing dependencies (i.e. missing plugins)
- added XMMS plugin (as a separate subpackage)
- added OpenIPMI plugin (as a separate subpackage)
- use bundled libnetlink (from iproute2) as the one that ships with openSUSE
  is not build with -fPIC, which causes linking to fail on x86_64
- split out a few plugins to avoid dependencies in the main package
- new upstream version
* Wed Apr 23 2008 guru@unixtech.be
- new upstream version
* Tue Apr  1 2008 guru@unixtech.be
- new upstream version
* Tue Feb 19 2008 guru@unixtech.be
- new upstream version
* Mon Jan 21 2008 guru@unixtech.be
- new upstream version
* Mon Dec 17 2007 guru@unixtech.be
- new upstream version
* Fri Nov  9 2007 guru@unixtech.be
- new upstream version
- promoted beta to stable
* Wed Oct 24 2007 guru@unixtech.be
- new upstream version
* Sun Sep 30 2007 guru@unixtech.be
- new upstream version
* Wed Sep 12 2007 guru@unixtech.be
- new upstream version
- forked off -beta
* Tue Sep 11 2007 guru@unixtech.be
- new upstream version
- moved to openSUSE Build Service
* Wed Aug 29 2007 guru@unixtech.be
- added --disable-nut, made the build fail
- new upstream version
* Mon Aug 13 2007 guru@unixtech.be
- fixed commented defaults in configuration file
- fixed init script
- dropped sysconfig
- fixed access rights on init script, thanks to Detlef for reporting
* Fri Aug  3 2007 guru@unixtech.be
- new upstream version
* Sun Jun 24 2007 guru@unixtech.be
- new upstream version
* Wed Jun 20 2007 guru@unixtech.be
- new upstream version
* Sat Jun 16 2007 guru@unixtech.be
- new upstream version
* Wed Jun  6 2007 guru@unixtech.be
- new upstream version
* Sun Jun  3 2007 guru@unixtech.be
- new upstream version
* Tue May 29 2007 guru@unixtech.be
- new upstream version
* Tue Apr 10 2007 guru@unixtech.be
- new upstream version
* Sun Apr  1 2007 guru@unixtech.be
- new upstream version
* Sun Feb 11 2007 guru@unixtech.be
- new upstream version
* Fri Feb  9 2007 guru@unixtech.be
- new upstream version
* Thu Nov  2 2006 guru@unixtech.be
- new upstream version
* Thu Jul 20 2006 guru@unixtech.be
- added %%%%{_sysconfdir}/collectd.conf
- new upstream version
* Thu Jun 15 2006 guru@unixtech.be
- added mysql support on SUSE >= 9.3 (older versions don't have the required
  version >= 4.1.0)
- moved configure to build section
- new upstream version
* Sun May 14 2006 guru@unixtech.be
- new upstream version
* Wed Apr 19 2006 guru@unixtech.be
- added patch to fix a warning with a pointer diff being passed to printf
- added stripping of binaries on SUSE < 9.3
- removed Packager and Distribution, injected by rpmmacros
- new upstream version
* Mon Apr 10 2006 guru@unixtech.be
- new upstream version
* Thu Apr  6 2006 guru@unixtech.be
- new upstream version
* Mon Mar 13 2006 guru@unixtech.be
- new upstream version
- added BuildRequires for suse-release
- removed explicit Requires that are found by AutoReqProv
* Mon Jan 30 2006 guru@unixtech.be
- new upstream version
- added manpage for collectd.conf
- added SMP flags to make
* Mon Jan 23 2006 guru@unixtech.be
- new upstream version
* Sun Dec 25 2005 guru@unixtech.be
- new upstream version
* Sun Dec  4 2005 guru@unixtech.be
- small fixes to Requires section
- new upstream version
* Tue Nov  8 2005 guru@unixtech.be
- had to specify --enable-serial to build the serial collect module (only on
  Linux)
- sanitized spec file
- new upstream version
* Thu Oct 27 2005 guru@unixtech.be
- new upstream version
* Tue Oct  4 2005 guru@unixtech.be
- made rc-link in sbin conditional (SUSE)
- moved sysconfig file to fillup
- added debuginfo support
- new upstream version
* Sun Sep 18 2005 guru@unixtech.be
- dropped no-chown patch
- added manpage
- added runtime dependency to libping-dping
- added build dependency to libstatgrab
- new upstream version: 2.1.0
* Sun Aug 21 2005 guru@unixtech.be
- version 1.6.0
* Sun Aug  7 2005 guru@unixtech.be
- new package
